/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Currency.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.composite;

/**
 * Currency is the Java representation of a monetary currency.
 */
public final class Currency {
    /***CONST****************************/
    public static final Currency usDollar = new Currency("USD", (byte)2);
    public static final Currency deutscheMark = new Currency("DEM", (byte)2);
    public static final Currency euro = new Currency("EUR", (byte)2);
    /***properties**************************/
    protected String code;
    protected byte digits;
    /***Constructor**************************/
    protected Currency(String _c, byte _d) {
	code = _c; digits = _d;
    }
    /***Object******************************/
    public String toString() {
	return "[Currency code="+code+" digits="+digits+"]";
    }
    public boolean equals(Object o) {
	if (o instanceof Currency) {
	    Currency c = (Currency)o;
	    return code.equals(c.getCode());
	} else
	    return false;
    }
    public int hashCode() {
	return code.hashCode();
    }
    /***Data*********************************/
    public String getCode() { return code; }
    public byte getDigits() { return digits; }
    /***Static****************************/
    public static Currency getByCode(String code) {
	// TODO
	return deutscheMark;
    }
}
