/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Money.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.composite;

/**
 * Money contains a monetary value.
 */
public final class Money {
    /***properties**************************/
    protected long value;
    protected Currency currency;
    /***Constructor**************************/
    public Money(long _v, Currency _c) {
	value = _v; currency = _c;
	if (currency==null)
	    throw new IllegalArgumentException("currency must not be null");
    }
    /***Object******************************/
    public String toString() {
	return "[Money value="+value+" currency="+currency+"]";
    }
    public boolean equals(Object o) {
	if (o instanceof Money) {
	    Money m = (Money)o;
	    return value==m.getValue() &&
		currency.equals(m.getCurrency());
	} else
	    return false;
    }
    /***Data**********************************/
    public long getValue() { return value; }
    public Currency getCurrency() { return currency; }
    public Money add(Money m) {
	if (!m.currency.equals(currency))
	    throw new IllegalArgumentException("wrong currency");
	return new Money(value+m.value, currency);
    }
    public Money negate() {
	return new Money(-value, currency);
    }
}
