/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MoneySum.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.composite;

import java.util.Hashtable;
import java.util.Enumeration;

/**
 * MoneySum contains a sum of several Money objects.
 * This is useful when adding several Money objects with 
 * different currencies.
 */
public final class MoneySum {
    /***properties**************************/
    protected Hashtable values = new Hashtable(2);
    /***Constructor**************************/
    /***Object******************************/
    public String toString() {
	StringBuffer sb = new StringBuffer("[MoneySum ");
	Enumeration enum = values.elements();
	if (enum.hasMoreElements()) {
	    sb.append(enum.nextElement().toString());
	    while (enum.hasMoreElements())
		sb.append(","+enum.nextElement().toString());
	}
	sb.append("]");
	return sb.toString();
    }
    public boolean equals(Object o) {
	if (o instanceof MoneySum) {
	    MoneySum m = (MoneySum)o;
	    // compare length
	    final int length = values.size();
	    if (length!=m.values.size())
		return false;
	    // compare elements
	    for (Enumeration enum=values.keys(); enum.hasMoreElements();) {
		Currency c = (Currency)enum.nextElement();
		Money m1 = (Money)values.get(c);
		Money m2 = (Money)m.values.get(c);
		if (!m1.equals(m2))
		    return false;
	    }
	    return true;
	} else
	    return false;
    }
    /***MoneySum*****************************/
    public void add(Money m) {
	Money m2 = (Money)values.get(m.getCurrency());
	if (m2!=null)
	    m = m2.add(m);
	values.put(m.getCurrency(), m);
    }
    public Enumeration getValues() {
	return values.elements();
    }
}
