/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DebugEmbeddedManager.java,v 1.10 2001/10/11 21:31:30 max Exp $
 *
 */

package make.datamodel.embedded;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.io.PrintWriter;
import java.util.Hashtable;
import org.w3c.dom.Node;
import org.w3c.dom.Document;
import org.xml.sax.SAXException;
import make.xml.DOMUtil;
import make.xml.DOMWriter;
import make.xml.DocumentType;
import make.xml.SchemaManager;

/**
 * EmbeddedManager implementation that dumps out
 * all commands to a PrintWriter. This is for debugging purposes.
 */
public class DebugEmbeddedManager implements EmbeddedManager {
    protected static final String ENCODING = "ISO-8859-1";
    /*properties*****************************/
    protected PrintWriter out;
    protected SchemaManager schemaManager;
    /*Constructor*****************************/
    /**
     * Creates a new instance.
     * @param _out the PrintWriter object to dump to
     * @param _fm the SchemaManager instance
     */
    public DebugEmbeddedManager(PrintWriter _out, SchemaManager _fm) {
	out = _out;
	schemaManager = _fm;
    }
    /**
     * Creates a new instance.
     * @param _out the Writer object to dump to
     * @param _fm the SchemaManager instance
     */
    public DebugEmbeddedManager(Writer _out, SchemaManager _fm) {
	this(new PrintWriter(_out), _fm);
    }
    /**
     * Creates a new instance that dumps to System.err
     * @param _fm the SchemaManager instance
     */
    public DebugEmbeddedManager(SchemaManager _fm) throws IOException {
	this(new OutputStreamWriter(System.err, ENCODING), _fm);
    }
    public String toString() { return "[DEBUG]"; }
    /*EmbeddedManager******************************************/
    public String[] getNames() {
	return new String[]{};
    }
    public Hashtable getSizes() {
	return new Hashtable();
    }
    public boolean contains(String name) {
	return false;
    }
    public void replaceEntry(String name, InputStream data)
	throws IOException {
	long size = 0;
	while (data.read()!=-1) size++;
	out.println("[DEBUG-EM] wrote entry '"+name+"' size="+size);
    }
    public InputStream getEntry(String name) throws IOException {
	return null;
    }
    public void replaceDocument(Node n) throws IOException {
	final Document doc = n.getOwnerDocument();
	DocumentType type = null;
	if (schemaManager!=null) {
	    String tn = schemaManager.getSchemaName(doc);
	    if (tn!=null)
		type = schemaManager.getSchema(tn);
	}
	out.println("[DEBUG-EM] replaced document:");
	DOMWriter dw = new DOMWriter(out, ENCODING);
	dw.setFormat(type);
	dw.print(doc);
	dw.flush();
	out.println("[DEBUG-EM] end of document");
    }
    public Node getDocument() throws IOException, SAXException {
	Document doc = DOMUtil.createDocument();
	Node el = doc.createElement("debug");
	doc.appendChild(el);
	return el;
    }
}
