/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: HashtableSlot.java,v 1.4 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.slot;

import java.util.Hashtable;
import java.text.ParseException;

/**
 * This Slot implementation stores its data in a Hashtable,
 * accessed with the specified key.
 */
public class HashtableSlot implements Slot {
    /*properties****************************/
    protected Hashtable ht;
    protected Object key;
    /*Constructor***************************/
    /**
     * Creates a new instance.
     * @param _ht the Hashtable object
     * @param _key the key value used to access the Hashtable
     */
    public HashtableSlot(Hashtable _ht, Object _key) {
	ht = _ht; key = _key;
    }
    /*Slot**********************************/
    public void setValue(Object v) throws ParseException {
	if (v==null)
	    ht.remove(key);
	else
	    ht.put(key, v);
    }
    public Object getValue() throws ParseException {
	return ht.get(key);
    }
}
