/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: LocalizedSlotContainerProxy.java,v 1.5 2002/01/03 08:01:05 max Exp $
 *
 */

package make.datamodel.slot;

import java.util.Collections;
import java.util.Collection;
import java.util.LinkedList;
import java.util.Iterator;
import java.util.Set;
import java.util.HashSet;
import java.util.Locale;
import java.text.ParseException;
import make.util.LocalizedString;

public class LocalizedSlotContainerProxy
    implements LocalizedSlotContainer {

    public class LocalizedSlotProxy
        implements Slot {
        /*properties***************/
        protected Slot parent;
        /*Constructor*********/
        public LocalizedSlotProxy(Slot _parent) {
            parent = _parent;
        }
        /*Slot****************/
        public void setValue(Object value)
            throws ParseException {
            if (value!=null && !(value instanceof String))
                throw new ParseException
                    ("wrong class: must be String, is "+
                     value.getClass(), 0);
            Object oldValue = parent.getValue();
            if (oldValue==null) {
                if (value!=null)
                    parent.setValue(new LocalizedString(locale, (String)value));
            } else if (oldValue instanceof LocalizedString) {
                LocalizedString oldValue2 = (LocalizedString)oldValue;
                if (value==null)
                    parent.setValue(oldValue2.remove(locale));
                else
                    parent.setValue(oldValue2.put(locale, (String)value));
            } else {
                throw new ParseException
                    ("wrong class: must be LocalizedString, is "+
                     oldValue.getClass(), 0);
            }
        }
        public Object getValue()
            throws ParseException {
            Object value = parent.getValue();
            if (value==null)
                return null;

            if (!(value instanceof LocalizedString))
                throw new ParseException
                    ("wrong class: must be LocalizedString, is "+
                     value.getClass(), 0);

            return ((LocalizedString)value).get(locale);
        }
    }

    /*properties****************************/
    protected SlotContainer parent;
    protected Locale locale;
    protected Collection slots = new LinkedList();

    /*Constructor****************************/
    public LocalizedSlotContainerProxy(SlotContainer _parent,
                                       Locale _locale) {
        parent = _parent;
        locale = _locale;
    }

    /*LocalizedSlotContainer*****************/
    public Locale getLocale() {
        return locale;
    }
    public boolean setLocale(Locale _locale) {
        locale = _locale;
        return true;
    }
    public Set getReferencedLocales() {
        Set locales = new HashSet();
        Iterator it = slots.iterator();
        while (it.hasNext()) {
            Slot slot = (Slot)it.next();
            try {
                Object value = slot.getValue();
                if (value instanceof LocalizedString) {
                    LocalizedString string = (LocalizedString)value;
                    Iterator it2 = string.locales().iterator();
                    while (it2.hasNext()) {
                        Locale locale = (Locale)it2.next();
                        if (locale!=null)
                            locales.add(locale);
                    }
                }
            } catch (ParseException e) {
                // ParseException is ignored here
            }
        }
        return Collections.unmodifiableSet(locales);
    }
    public void deleteLocale(Locale locale) {
        Iterator it = slots.iterator();
        while (it.hasNext()) {
            Slot slot = (Slot)it.next();
            try {
                Object value = slot.getValue();
                if (value instanceof LocalizedString) {
                    LocalizedString string = (LocalizedString)value;
                    slot.setValue(string.remove(locale));
                }
            } catch (ParseException e) {
                // ParseException is ignored here
            }
        }
    }

    /*SlotContainer**************************/
    public Slot getSlot(Object key) {
        Slot slot = parent.getSlot(key);
        if (slot==null)
            return null;

        slots.add(slot);
        return new LocalizedSlotProxy(slot);
    }
}
