/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2002 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ReflectionSlotContainer.java,v 1.1 2002/01/03 12:22:20 max Exp $
 *
 */

package make.datamodel.slot;

import java.lang.reflect.Method;
import java.util.Set;
import java.util.Map;

public class ReflectionSlotContainer implements SlotContainer {
    /*properties***************************/
    protected Object object;
    protected Class defaultPropertyClass = Object.class;
    protected Set propertyNames;
    protected Map propertyClasses;
    /*Constructor***************************/
    public ReflectionSlotContainer(Object _obj) {
        object = _obj;
    }
    public ReflectionSlotContainer(Object _obj,
                                   Class _defPropCls) {
        this(_obj);
        defaultPropertyClass = _defPropCls;
    }
    public ReflectionSlotContainer(Object _obj, Set _propNames) {
        this(_obj);
        propertyNames = _propNames;
    }
    public ReflectionSlotContainer(Object _obj, Set _propNames,
                                   Class _defPropCls) {
        this(_obj, _propNames);
        defaultPropertyClass = _defPropCls;
    }
    public ReflectionSlotContainer(Object _obj, Set _propNames,
                                   Map _propClasses) {
        this(_obj, _propNames);
        propertyClasses = _propClasses;
    }
    public ReflectionSlotContainer(Object _obj, Map _propClasses) {
        this(_obj, _propClasses.keySet(), _propClasses);
    }
    /*SlotContainer****************************/
    public Slot getSlot(Object key) {
        if (!(key instanceof String))
            return null;
        String name = (String)key;
        if (name.equals(""))
            return null;
        if (propertyNames!=null && !propertyNames.contains(name))
            return null;
        name = name.substring(0,1).toUpperCase() + name.substring(1);
        Class cls = object.getClass();
        Method getMethod;
        try {
            getMethod = cls.getMethod("get"+name, null);
        } catch (NoSuchMethodException e) {
            getMethod = null;
        }
        Method setMethod;
        try {
            Class pcls = propertyClasses==null
                ? null : (Class)propertyClasses.get(key);
            if (pcls==null)
                pcls = defaultPropertyClass;
            setMethod = cls.getMethod("set"+name, new Class[]{pcls});
        } catch (NoSuchMethodException e) {
            setMethod = null;
        }
        if (getMethod==null && setMethod==null)
            return null;
        return new ReflectionSlot(object, getMethod, setMethod);
    }
}
