/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Slot.java,v 1.5 2001/08/20 09:23:38 max Exp $
 *
 */

package make.datamodel.slot;

import java.text.ParseException;

/**
 * A slot in MakeLib is an object which can store a value. You can set
 * and request this value. Before setting a value, the slot checks
 * whether this value is valid, and before returning a value, the slot
 * checks whether it has got a valid value. Slot is the base interface
 * for a few other interfaces, e.g. Field.
 */
public interface Slot {
    /**
     * Assigns a new value.
     * @param v the new value
     * @exception ParseException if the specified value is not acceptable
     */
    void setValue(Object v) throws ParseException;
    /**
     * Retrieves the value.
     * @return the current value
     * @exception ParseException if the data source contains
     *                           a value that is not acceptable
     */
    Object getValue() throws ParseException;
}
