/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MultiPartEncoder.java,v 1.3 2001/08/20 09:23:38 max Exp $
 *
 */

package make.mime;

import java.util.Enumeration;
import java.util.Random;
import java.io.IOException;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.PrintWriter;
import make.io.Streams;

public class MultiPartEncoder {
    protected static final String CRLF = "\r\n";
    protected static Random random = new Random();
    /***properties****************************/
    protected String boundary
	= "MultiPartEncoder-boundary----"+random.nextLong();
    protected OutputStream out;
    /***Constructor*****************************/
    public MultiPartEncoder(OutputStream _out) {
	out = _out;
    }
    public String getContentType() {
	return "multipart/mixed; boundary="+boundary;
    }
    public void writeMessage(Message msg)
	throws IOException {
	OutputStreamWriter wr = new OutputStreamWriter(out, "us-ascii");
	PrintWriter ps = new PrintWriter(wr);
	ps.print(CRLF);
	ps.print("--"+boundary+CRLF);
	for (Enumeration enum=msg.getHeaderNames();
	     enum.hasMoreElements();) {
	    String name = (String)enum.nextElement();
	    String value = msg.getHeader(name);
	    ps.print(name+": "+value+CRLF);
	}
	ps.print(CRLF);
	ps.flush();
	wr.flush();
	Streams.copy(msg.getInputStream(), out);
    }
    public void close() throws IOException {
	OutputStreamWriter wr = new OutputStreamWriter(out, "us-ascii");
	PrintWriter ps = new PrintWriter(wr);
	ps.print(CRLF);
	ps.print("--"+boundary+"--"+CRLF);
	ps.flush();
	wr.flush();
    }
}
