/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ClassResourceLoader.java,v 1.2 2001/08/20 09:23:38 max Exp $
 *
 */

package make.module;

import java.io.IOException;
import java.io.InputStream;
import java.io.ByteArrayOutputStream;
import java.net.URL;
import make.util.Debug;
import make.io.Streams;

/**
 * This class is a ResourceLoader that can load its data
 * from a java.lang.Class
 */
public class ClassResourceLoader 
    implements ResourceLoader {
    /*properties***************************/
    protected Class cls;
    /*Constructor*************************/
    /**
     * Creates a new ResourceLoader implementation.
     * @param _cl the Class object where resources can be found
     */
    public ClassResourceLoader(Class _cl) {
	cls = _cl;
    }
    /*ResourceLoader***************************/
    public URL getResource(String name) {
	return cls.getResource(name);
    }
    public InputStream getResourceAsStream(String name) {
	return cls.getResourceAsStream(name);
    }
    public byte[] loadResource(String name) {
	InputStream is = getResourceAsStream(name);
	if (is==null)
	    return null;
	ByteArrayOutputStream baos = new ByteArrayOutputStream();
	try {
	    Streams.copy(is, baos);
	    return baos.toByteArray();
	} catch (IOException e) {
	    Debug.report(e);
	    return null;
	} finally {
	    try {
		baos.close();
		is.close();
	    } catch (IOException e) {
		Debug.report(e);
	    }
	}
    }
}
