/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MapResourceLoader.java,v 1.1 2001/10/11 22:30:46 max Exp $
 *
 */

package make.module;

import java.io.InputStream;
import java.io.ByteArrayInputStream;
import java.net.URL;
import java.util.Map;

/**
 * MapResourceLoader loads resources from a java.util.Map object.
 */
public class MapResourceLoader 
    implements ResourceLoader {
    /*properties*******************************/
    protected Map map;
    /*Constructor******************************/
    /**
     * Creates a new ResourceLoader instance
     * @param _map the Map object
     */
    public MapResourceLoader(Map _map) {
	map = _map;
    }
    public String toString() {
	return "[MapResourceLoader map="+map+"]";
    }
    protected String normalizeName(String name) {
	while (name.startsWith(".") || name.startsWith("//"))
	    name = name.substring(1);
	if (!name.startsWith("/"))
	    name = '/'+name;
	return name;
    }
    /*ResourceLoader***************************/
    public URL getResource(String name) {
	return null;
    }
    public InputStream getResourceAsStream(String name) {
	byte[] data = loadResource(name);
	if (data==null)
	    return null;
	return new ByteArrayInputStream(data);
    }
    public byte[] loadResource(String name) {
	return (byte[])map.get(normalizeName(name));
    }
}
