/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PathModuleRepository.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.module;

import java.io.File;
import java.io.IOException;
import java.util.Enumeration;
import java.util.Hashtable;
import make.util.Debug;

/**
 * This ModuleRepository implementation searches for
 * installed modules in a filesystem path.
 * For every directory, a PathResourceLoader is created,
 * and for every JAR or ZIP file, a ZipResourceLoader is created.
 */
public class PathModuleRepository 
    implements ModuleRepository {
    /*properties*************************/
    protected File path;
    protected Hashtable modules = new Hashtable();
    /*Constructor*************************/
    /**
     * Creates a new ModuleRepository instance.
     * @param _p the path where to search for modules
     */
    public PathModuleRepository(File _p) {
	path = _p;
	String[] list = path.list();
	for (int z=0; z<list.length; z++) {
	    File f = new File(path, list[z]);
	    if (!f.canRead())
		continue;
	    if (f.isDirectory()) {
		modules.put(list[z], new PathResourceLoader(f));
	    } else if (f.isFile()) {
		if (list[z].endsWith(".jar") || 
		    list[z].endsWith(".zip")) {
		    int dotidx = list[z].indexOf('.');
		    String name = list[z].substring(0, dotidx);
		    File subdir = new File(path, name);
		    if (!subdir.canRead() || !subdir.isDirectory())
			try {
			    modules.put(name, new ZipResourceLoader(f));
			} catch (IOException e) {
			    Debug.report(e);
			}
		}
	    }
	}
    }
    /*ModuleRepository*********************/
    public Enumeration getModuleNames() {
	return modules.keys();
    }
    public ResourceLoader getModule(String name) {
	return (ResourceLoader)modules.get(name);
    }
}
