/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PrefixResourceLoader.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.module;

import java.io.InputStream;
import java.net.URL;

/**
 * PrefixResourceLoader is an adapter for an existing
 * ResourceLoader instance. It prepends a specified prefix string
 * before chaining the function calls to the original ResourceLoader.
 * This is useful when loading WAR files (web archives):
 * here you need the prefix WEB-INF to load classes correctly.
 */
public class PrefixResourceLoader
    implements ResourceLoader {
    /*properties*********************/
    protected ResourceLoader resourceLoader;
    protected String prefix;
    /*Constructor********************/
    /**
     * Creates a new ResourceLoader instance.
     * @param _rl the original ResourceLoader
     * @param _pre the prefix
     */
    public PrefixResourceLoader(ResourceLoader _rl, String _pre) {
	resourceLoader = _rl;
	prefix = _pre;
    }
    public String toString() {
	return "[PrefixResourceLoader rl="+resourceLoader+
	    " prefix="+prefix+"]";
    }
    /**
     * Internally translates a resource name.
     */
    protected String translate(String name) {
	while (!Character.isJavaIdentifierPart(name.charAt(0)))
	    name = name.substring(1);
	return prefix+"/"+name;
    }
    /*ResourceLoader*************************/
    public URL getResource(String name) {
	return resourceLoader.getResource(translate(name));
    }
    public InputStream getResourceAsStream(String name) {
	return resourceLoader.getResourceAsStream(translate(name));
    }
    public byte[] loadResource(String name) {
	return resourceLoader.loadResource(translate(name));
    }
}
