/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Trustee.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.scheduler;

/**
 * Trustee is an object that maintains some kind of object.
 * It is run regularly and then performs small portions of its work.
 * If it has still got work left after that, it wants to be called
 * again after a shorter amount of time.
 */
public interface Trustee {
    /**
     * Returns the delay in milliseconds after which this
     * object wants to be run again in the case it has still 
     * got work left.
     */
    long getBusyDelay();
    /**
     * Returns the delay in milliseconds after which this
     * object wants to be run again in the case it is in idle.
     */
    long getStandbyDelay();
    /**
     * Runs the Trustee.
     * @return true if it is busy, and false if it is in idle
     */
    boolean run() throws Exception;
}
