/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DOMConnectionFactory.java,v 1.1 2001/11/08 22:29:40 max Exp $
 *
 */

package make.sql;

import java.sql.Connection;
import java.sql.SQLException;
import java.sql.DriverManager;
import java.io.File;
import java.io.IOException;
import org.xml.sax.SAXException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import make.util.Debug;
import make.xml.DOMUtil;

/**
 * A ConnectionFactory implementation that loads its database
 * connect strings and passwords from a DOM tree.
 */
public class DOMConnectionFactory implements ConnectionFactory {
    /*properties********************************/
    protected int poolSize;
    protected String url, user, password;
    /*Constructor************************************/
    /**
     * Creates a new instance.
     */
    public DOMConnectionFactory(Element _root) {
        loadConfig(_root);
    }
    /**
     * Creates a new instance.
     */
    public DOMConnectionFactory(Document _doc) {
        this(_doc.getDocumentElement());
    }
    /**
     * Creates a new instance that parses an XML file.
     */
    public DOMConnectionFactory(File _file) 
        throws IOException, SAXException {
        this(DOMUtil.parse(_file, "ISO-8859-1"));
    }
    public String toString() {
        return "DOMConnectionFactory[url="+url+"]";
    }
    protected void loadConfig(Element root) {
        String poolSizeString
            = DOMUtil.getElementString(root, "poolsize");
        poolSize = poolSizeString==null
            ?1
            :Integer.parseInt(poolSizeString);
        String _driver = DOMUtil.getElementString(root, "driver");
        if (_driver!=null)
            try {
                Class.forName(_driver);
            } catch (Exception e) {
                Debug.report(e, "trying to register JDBC driver "+_driver);
            }
        url = DOMUtil.getElementString(root, "url");
        user = DOMUtil.getElementString(root, "username");
        password = DOMUtil.getElementString(root, "password");
    }
    /**
     * Returns the maximum number of concurrent connections.
     */
    public int getPoolSize() {
        return poolSize;
    }
    /*ConnectionFactory***************************/
    public Connection createConnection() throws SQLException {
        return DriverManager.getConnection(url, user, password);
    }
}
