/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: GenericButton.java,v 1.5 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.awt.event.ActionListener;

/**
 * GenericButton instances are objects which can emit
 * ActionEvents. 
 * This may be a button on the screen where the user can click
 * with the mouse or a hotkey the user can press.
 */
public interface GenericButton {
    /**
     * Returns the object that will be the source of events.
     */
    Object getActionSource();
    /**
     * Returns the action command.
     */
    String getActionCommand();
    /**
     * Registers an object as listener for events.
     */
    void addActionListener(ActionListener al);
    /**
     * Unregisters an object as listener for events.
     */
    void removeActionListener(ActionListener al);
    /**
     * Enables or disables this button.
     * Applications must consider that even a disabled button
     * can emit actions. This should only be a hint for the user interface,
     * and should not be integrated in the program logic.
     * i.e. the application must still check if the action is valid.
     */
    void setEnabled(boolean _e);
    /**
     * Selects or deselects the action.
     * The meaning of this depends on the implementation.
     * Useful for check boxes or checkbox menu items.
     */
    void setSelected(boolean _p);
}
