/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: SortedTableHeaderRenderer.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.awt.Component;
import java.awt.Graphics;
import java.awt.Dimension;
import javax.swing.JTable;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.JTableHeader;
import javax.swing.UIManager;

/**
 * This TableCellRenderer implementation renders
 * table headers and shows in which way the columns are sorted.
 *
 * This object does NOT sort, it only shows which column is sorted.
 */
public class SortedTableHeaderRenderer extends DefaultTableCellRenderer {
    /*properties***************************************/
    protected JTableHeader header;
    protected int sortedColumnIndex = -1;
    protected boolean sortDescending = false;
    protected boolean drawSortIcon = false;
    /*Constructor************************************/
    public SortedTableHeaderRenderer(JTableHeader _h, int idx, boolean desc) {
	setSortColumn(idx, desc);
	header = _h;
    }
    /*Public***************************************/
    /**
     * Tells the renderer which column is sorted.
     * Only one column can be sorted at a time.
     * @param idx the index of the sorted column
     * @param desc is true if it is sorted descending
     */
    public void setSortColumn(int idx, boolean desc) {
	sortedColumnIndex = idx;
	sortDescending = desc;
	if (header!=null)
	    header.invalidate();
    }
    /*Component***************************************/
    public void paint(Graphics g) {
	super.paint(g);
	if (drawSortIcon) {
	    final Dimension d = getSize();
	    final int height = d.height-6;
	    final int width = (height*4)/3;
	    final int maxX = d.width - 4;
	    final int minX = maxX - width;
	    final int minY = 2;
	    final int maxY = minY + height;
	    int[] x = new int[3];
	    int[] y = new int[3];
	    x[0] = (minX+maxX)/2;
	    x[1] = maxX;
	    x[2] = minX;
	    if (sortDescending) {
		y[0] = minY;
		y[1] = maxY;
		y[2] = maxY;
	    } else {
		y[0] = maxY;
		y[1] = minY;
		y[2] = minY;
	    }
	    g.setColor(UIManager.getColor("textInactiveText"));
	    g.drawPolygon(x, y, 3);
	}
    }    
    /*TableCellRenderer**********************************/
    public Component getTableCellRendererComponent(JTable table, Object value, 
						   boolean isSelected,
						   boolean hasFocus, int row, int column) {
	if (header!=null) {
	    setForeground(header.getForeground());
	    setBackground(header.getBackground());
	    setFont(header.getFont());
	}
	setText(value==null?"":value.toString());
	setBorder(UIManager.getBorder("TableHeader.cellBorder"));
	drawSortIcon = sortedColumnIndex==column;
	return this;
    }
}
