/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: TextButton.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing;

import java.awt.event.ActionListener;
import javax.swing.JTextField;

/**
 * GenericButton implementation that retrieves
 * ActionEvents from a JTextField.
 * The action is fired by JTextField when the user
 * presses Return while the field is focused.
 */
public class TextButton implements GenericButton {
    /*properties****************************/
    protected JTextField bt;
    protected String command;
    /*Constructor**************************/
    /**
     * Creates a new instance.
     * @param _bt the JTextField object
     * @param _cmd the action command
     */
    public TextButton(JTextField _bt, String _cmd) { 
	bt = _bt;
	command = _cmd;
	bt.setActionCommand(command);
    }
    public String toString() {
	return "TextButton("+bt+")";
    }
    /*GenericButton*************************/
    public Object getActionSource() { 
	return bt; 
    }
    public String getActionCommand() { 
	return command;
    }
    public void addActionListener(ActionListener al) {
	bt.addActionListener(al);
    }
    public void removeActionListener(ActionListener al) {
	bt.removeActionListener(al);
    }
    public void setEnabled(boolean _e) {
    }
    public void setSelected(boolean _p) {
    }
}
