/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ButtonDescription.java,v 1.10 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.bt;

import java.util.Locale;
import java.net.URL;
import javax.swing.KeyStroke;
import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JMenuItem;
import org.w3c.dom.Element;
import make.xml.DOMUtil;
import make.util.Strings;

public class ButtonDescription {
    public static final String NAME = "BD_NAME";
    /***properties****************************/
    protected String name, actionCommand, label, tooltip;
    protected char mnemonic = 0;
    protected KeyStroke accelerator;
    protected Icon icon;
    /***Constructor**************************/
    public ButtonDescription(String _n, String _ac, String _l, String _tt, 
                             char _mn, KeyStroke _acc, Icon _icon) {
        name = _n; actionCommand = _ac;
        label = _l; tooltip = _tt;
        mnemonic = _mn;
        accelerator = _acc; 
        icon = _icon;
    }
    public ButtonDescription(String _n, String _label) {
        this(_n, _n, _label, null, (char)0, null, null);
    }
    public ButtonDescription(Element vd, Class cls, Locale locale) {
        name = vd.getAttribute("name");
        actionCommand = Strings.trim(vd.getAttribute("action"));
        if (actionCommand==null)
            actionCommand = name;
        tooltip = DOMUtil.getLocalizedElementString
            (vd, "tooltip", locale, false);
        if (tooltip==null)
            tooltip = label;
        Element lbl = DOMUtil.getLocalizedUniqueTag
            (vd, "label", locale);
        label = DOMUtil.getElementString(lbl);
        if (lbl!=null) {
            String mn = lbl.getAttribute("mnemonic");
            if (mn!=null && mn.length()>0)
                mnemonic = mn.charAt(0);
        }
        String accel = DOMUtil.getLocalizedElementString
            (vd, "accelerator", locale, false);
        if (accel!=null)
            accelerator = KeyStroke.getKeyStroke(accel);
        String iconString = DOMUtil.getElementString(vd, "icon");
        if (iconString!=null){
            // compatibility with old config files
            if (iconString.startsWith("/com/make/editor/"))
                iconString = "/org/leanedit/" + iconString.substring(17);
            URL iconURL = cls.getResource(iconString);
            if (iconURL!=null)
                icon = new ImageIcon(iconURL);
        }
    }
    /***Info****************************/
    public String getName() { return name; }
    /***Factory*****************************/
    public AbstractButton createToolBarButton() {
        ToolBarButton b = new ToolBarButton();
        if (icon==null) {
            b.setText(label);
            if (mnemonic!=0)
                b.setMnemonic(mnemonic);
        } else
            b.setIcon(icon);
        b.setEnabled(false);
        if (tooltip!=null)
            b.setToolTipText(tooltip);
        b.putClientProperty(NAME, name);
        b.setActionCommand(actionCommand);
        return b;
    }
    public AbstractButton createButton() {
        JButton b = new JButton(label);
        b.setActionCommand(actionCommand);
        b.setEnabled(false);
        if (tooltip!=null)
            b.setToolTipText(tooltip);
        b.putClientProperty(NAME, name);
        return b;
    }
    public AbstractButton createMenuItem() {
        JMenuItem mi = new JMenuItem(label, icon);
        if (mnemonic!=0)
            mi.setMnemonic(mnemonic);
        mi.setActionCommand(actionCommand);
        mi.setEnabled(false);
        if (tooltip!=null)
            mi.setToolTipText(tooltip);
        if (accelerator!=null)
            mi.setAccelerator(accelerator);
        mi.putClientProperty(NAME, name);
        return mi;
    }
}
