/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FrameDescription.java,v 1.19 2001/12/27 06:34:12 max Exp $
 *
 */

package make.swing.bt;

import java.util.Hashtable;
import java.util.Vector;
import java.util.ResourceBundle;
import java.util.Locale;
import java.awt.Component;
import java.awt.Container;
import java.awt.Dimension;
import javax.swing.JComponent;
import javax.swing.JToolBar;
import javax.swing.JMenuBar;
import javax.swing.JMenu;
import javax.swing.AbstractButton;
import javax.swing.Box;
import javax.swing.RootPaneContainer;
import org.w3c.dom.Element;
import make.xml.DOMUtil;
import make.util.Strings;
import make.util.Resources;
import make.swing.SwingButton;

public class FrameDescription implements ButtonContainer {
    /*static******************************/
    private static final ResourceBundle resources
        = Resources.getResourceBundle(FrameDescription.class.getClassLoader(),
                                      "make.swing.Dialog");
    protected static final ButtonDescription[] okCancelButtons = {
        new ButtonDescription("ok", resources.getString("ok.label")),
        new ButtonDescription("cancel", resources.getString("cancel.label")),
    };
    protected static final ButtonDescription[] closeButtons = {
        new ButtonDescription("close-frame", resources.getString("close.label")),
    };
    public static final FrameDescription okCancelDescription;
    public static final FrameDescription closeDescription;
    static {
        okCancelDescription = new FrameDescription();
        okCancelDescription.setButtonBox(okCancelButtons);
        closeDescription = new FrameDescription();
        closeDescription.setButtonBox(closeButtons);
    }
    /*properties*************************/
    protected String title;
    protected Dimension size;
    protected Hashtable buttons = new Hashtable();
    protected ButtonDescription[] toolBar;
    private Boolean toolBarFloatable;
    protected ButtonDescription[] buttonBox;
    protected BarDescription[] menuBar;
    /*Constructor************************/
    public FrameDescription() {
    }
    public FrameDescription(String _t) {
        title = _t;
    }
    public FrameDescription(Element d, Class cls, Locale locale) {
        title = DOMUtil.getLocalizedElementString(d, "title", locale, false);
        Element sz = DOMUtil.getUniqueTag(d, "size");
        if (sz!=null) {
            size = new Dimension(Integer.parseInt(sz.getAttribute("width")),
                                 Integer.parseInt(sz.getAttribute("height")));
        }
        // buttons
        Element buts = DOMUtil.getUniqueTag(d, "buttons");
        if (buts!=null) {
            Element[] bts = DOMUtil.getChildElements(buts);
            for (int z=0; z<bts.length; z++) {
                ButtonDescription bd = new ButtonDescription(bts[z], cls, locale);
                buttons.put(bd.getName(), bd);
            }
        }
        // toolbar
        Element toolb = DOMUtil.getUniqueTag(d, "toolbar");
        if (toolb!=null) {
            String fl = Strings.trim(toolb.getAttribute("floatable"));
            if ("yes".equals(fl))
                toolBarFloatable = Boolean.TRUE;
            if ("no".equals(fl))
                toolBarFloatable = Boolean.FALSE;
            Element[] tbs = DOMUtil.getChildElements(toolb);
            toolBar = new ButtonDescription[tbs.length];
            for (int z=0; z<tbs.length; z++) {
                String tag = tbs[z].getTagName();
                if (tag.equals("buttonref")) {
                    String name = tbs[z].getAttribute("name");
                    toolBar[z] = getButton(name);
                } else if (!tag.equals("separator"))
                    System.err.println("WARNING: unknown toolbar button "+tag);
            }
        }
        // buttonbox
        Element bb = DOMUtil.getUniqueTag(d, "buttonbox");
        if (bb!=null) {
            Element[] tbs = DOMUtil.getChildElements(bb);
            buttonBox = new ButtonDescription[tbs.length];
            for (int z=0; z<tbs.length; z++) {
                String tag = tbs[z].getTagName();
                if (tag.equals("buttonref")) {
                    String name = tbs[z].getAttribute("name");
                    buttonBox[z] = getButton(name);
                } else
                    System.err.println("WARNING: unknown buttonBox button "+tag);
            }
        }
        // menubar
        Element mbar = DOMUtil.getUniqueTag(d, "menubar");
        if (mbar!=null) {    
            Element[] mbs = DOMUtil.getChildElements(mbar);
            menuBar = new BarDescription[mbs.length];
            for (int z=0; z<mbs.length; z++) {
                String tag = mbs[z].getTagName();
                if (tag.equals("menu"))
                    menuBar[z] = new MenuDescription(this, mbs[z], cls, locale);
                else
                    System.err.println("WARNING: unknown menu container "+tag);
            }
        }
    }
    /*Modify***********************************/
    public void setOkCancel() {
        buttonBox = okCancelButtons;
        for (int z=0; z<buttonBox.length; z++)
            buttons.put(buttonBox[z].getName(), buttonBox);
    }
    public void setSize(Dimension _size) {
        size = _size;
    }
    public void setButtonBox(ButtonDescription[] bbx) {
        buttonBox = bbx;
        for (int z=0; z<buttonBox.length; z++)
            buttons.put(buttonBox[z].getName(), buttonBox);
    }
    /*Info*****************************************/
    public String getTitle() { return title; }
    public Dimension getSize() { return size; }
    /*ButtonContainer******************************/
    public ButtonDescription getButton(String name) {
        return (ButtonDescription)buttons.get(name);
    }
    /*Install***************************************/
    public void installPosition(Component c) {
        if (size==null)
            return;
        if (c instanceof RootPaneContainer)
            c = ((RootPaneContainer)c).getRootPane();
        if (c instanceof JComponent)
            ((JComponent)c).setPreferredSize(size);
        else
            c.setSize(size);
    }
    public JToolBar installToolBar(JToolBar tb, Vector bts, Vector cps) {
        if (toolBar!=null) {
            Component last;
            if (tb==null) {
                tb = new JToolBar();
                tb.setFloatable(false);
                last = Box.createGlue();
            } else {
                last = tb.getComponent(tb.getComponentCount()-1);
                tb.remove(last);
            }
            for (int z=0; z<toolBar.length; z++) {
                if (toolBar[z]==null) {
                    Component c = Box.createRigidArea(new Dimension(5,5));
                    tb.add(c);
                    cps.addElement(c);
                } else {
                    AbstractButton bt = toolBar[z].createToolBarButton();
                    bts.addElement(new SwingButton(bt));
                    tb.add(bt);
                    cps.addElement(bt);
                }
            }
            tb.add(last);
            tb.validate();
        }
        if (tb!=null && toolBarFloatable!=null) {
            tb.setFloatable(toolBarFloatable.booleanValue());
        }
        return tb;
    }
    public Container installButtonBox(Container box, Vector bts, Vector cps) {
        if (buttonBox==null)
            return box;
        if (box==null) {
            box = Box.createHorizontalBox();
            box.add(Box.createGlue());
        }
        for (int z=0; z<buttonBox.length; z++) 
            if (buttonBox[z]!=null) {
                AbstractButton bt = buttonBox[z].createButton();
                bts.addElement(new SwingButton(bt));
                box.add(bt);
                cps.addElement(bt);
            }
        box.validate();
        return box;
    }
    public JMenuBar installMenuBar(JMenuBar mb, Vector bts, Vector cps) {
        if (menuBar==null)
            return mb;
        if (mb==null)
            mb = new JMenuBar();
        for (int z=0; z<menuBar.length; z++)
            if (menuBar[z]!=null)
                menuBar[z].install(mb, bts, cps);
        mb.validate();
        return mb;
    }
}
