/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: PopupMenuDescription.java,v 1.7 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.bt;

import java.util.Vector;
import java.util.Locale;
import java.awt.Component;
import java.awt.Container;
import javax.swing.JComponent;
import javax.swing.AbstractButton;
import javax.swing.JSeparator;
import org.w3c.dom.Element;
import make.util.Strings;
import make.swing.SwingButton;

public class PopupMenuDescription extends BarDescription {
    /*CONST********************************/
    public static final String MENU = "FD_MENU";
    /*properties**************************/
    protected String itemsBefore, itemsAfter;
    protected ButtonDescription[] children;
    /*Constructor****************************/
    public PopupMenuDescription(ButtonContainer _bc, Element d,
                                Class cls, Locale locale) {
        super(_bc);
        itemsBefore = Strings.trim(d.getAttribute("before"));
        itemsAfter = Strings.trim(d.getAttribute("after"));
        children = loadChildren(d, cls, locale);
    }
    /*Internal**********************************/
    protected JComponent createComponent(ButtonDescription bd, Vector bts, Vector cps) {
        AbstractButton ab = bd.createMenuItem();
        bts.addElement(new SwingButton(ab));
        cps.addElement(ab);
        return ab;
    }
    protected int findChildIndex(Container c, String name) {
        Component[] ms = c.getComponents();
        for (int z=0; z<ms.length; z++)
            if (ms[z] instanceof JComponent &&
                name.equals(((JComponent)ms[z]).getClientProperty(ButtonDescription.NAME)))
                return z;
        return -1;
    }
    protected Component findChild(Container c, String name) {
        int idx = findChildIndex(c, name);
        return idx==-1 ? null : c.getComponent(idx);
    }
    protected void install(Container menu, int idx, Vector bts, Vector cps) {
        Object mn = menu instanceof JComponent
            ?((JComponent)menu).getClientProperty(MENU)
            :null;
        for (int z=0; z<children.length; z++,idx++)
            if (children[z]==null) {
                JComponent jc = new JSeparator();
                jc.putClientProperty(MENU, mn);
                cps.addElement(jc);
                menu.add(jc, idx);
            } else {
                JComponent jc = createComponent(children[z], bts, cps);
                jc.putClientProperty(MENU, mn);
                menu.add(jc, idx);
            }
    }
    /*PopupMenuDescription***************************/
    protected Container getMenu(Container c) {
        return c;
    }
    /*BarDescription**********************************/
    public Container install(Container c, Vector bts, Vector cps) {
        Container menu = getMenu(c);
        int idx = -1;
        if (itemsBefore!=null)
            idx = findChildIndex(menu, itemsBefore);
        if (idx==-1 && itemsAfter!=null) {
            idx = findChildIndex(menu, itemsAfter);
            if (idx!=-1)
                idx++;
        }
        if (idx==-1)
            idx = menu.getComponentCount();
        install(menu, idx, bts, cps);
        return menu;
    }
}
