/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DateField.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.field;

import java.text.ParseException;
import java.text.DateFormat;
import java.util.Date;
import make.util.Strings;

public class DateField extends TextField {
    /***CONST********************************/
    public static final int DATETIME = Strings.DATETIME;
    public static final int DATE = Strings.DATE;
    public static final int TIME = Strings.TIME;
    /***static*****************************/
    public static final DateFormat[] parseFormats = Strings.displayDateFormats;
    /***properties**************************/
    protected DateFormat storeFormat, displayFormat;
    /***Constructor**************************/
    public DateField(boolean storeString, int fmt) {
	storeFormat = storeString?Strings.storeDateFormats[fmt]:null;
	displayFormat = Strings.displayDateFormats[fmt];
    }
    public DateField(DateFormat sf, DateFormat df) {
	storeFormat = sf;
	displayFormat = df;
    }
    /***Field******************************/
    public Object getValue() throws ParseException {
	String s = (String)super.getValue();
	if (s==null)
	    return null;
	Date v = null;
	try {
	    v = displayFormat.parse(s);
	} catch (ParseException e) {
	    for (int z=0; z<parseFormats.length; z++)
		try {
		    v = parseFormats[z].parse(s);
		    break;
		} catch (ParseException e2) {
		}
	    if (v==null)
		throw new ParseException(messages.getString("error.date"), 0);
	}
	return storeFormat==null
	    ?(Object)v
	    :storeFormat.format(v);
    }
    public void setValue(Object _v) throws ParseException {
	if (_v==null)
	    super.setValue(_v);
	else {
	    Date v;
	    if (_v instanceof String)
		v = storeFormat.parse((String)_v);
	    else
		v = (Date)_v;
	    super.setValue(displayFormat.format(v));
	}
    }
}
