/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ListField.java,v 1.5 2001/10/30 16:41:42 max Exp $
 *
 */

package make.swing.field;

import java.util.Map;
import java.util.Collection;
import java.util.List;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.StringTokenizer;
import java.awt.Component;
import java.text.ParseException;
import javax.swing.ListCellRenderer;
import javax.swing.ListSelectionModel;
import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.event.ListSelectionListener;
import javax.swing.event.ListSelectionEvent;

public class ListField extends DefaultField 
    implements ListCellRenderer,
               ListSelectionListener {
    /*properties**************************/
    protected final Object nullValue = this;
    protected JList component;
    protected ListSelectionModel selectionModel;
    protected JScrollPane scrollPane;
    protected Map map;
    protected List list = new ArrayList();
    protected Collection notFound = new ArrayList();
    protected String delimiter;
    protected ListCellRenderer renderer;
    /*Constructor************************/
    public ListField(Map _map, String _delim) {
        map = _map;
        delimiter = _delim;
        if (map!=null)
            list.addAll(map.keySet());
        component = new JList(list.toArray());
        component.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        component.getSelectionModel().addListSelectionListener(this);
        selectionModel = component.getSelectionModel();
        renderer = component.getCellRenderer();
        component.setCellRenderer(this);
        scrollPane = new JScrollPane
            (component, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, 
             JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
        setComponent(scrollPane);
    }
    public ListField(Collection c, String _delim) {
        delimiter = _delim;
        if (c!=null)
            list.addAll(c);
        component = new JList(list.toArray());
        component.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
        component.getSelectionModel().addListSelectionListener(this);
        selectionModel = component.getSelectionModel();
        renderer = component.getCellRenderer();
        component.setCellRenderer(this);
        scrollPane = new JScrollPane
            (component, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, 
             JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
        setComponent(scrollPane);
    }
    /*ListCellRenderer*************************/
    public Component getListCellRendererComponent(JList _list, Object value,
                                                  int index,
                                                  boolean isSelected,
                                                  boolean cellHasFocus) {
        if (value==nullValue)
            value = null;
        Object vDisplay;
        if (map==null)
            vDisplay = value;
        else
            vDisplay = map.get(value);
        if (vDisplay==null)
            vDisplay = value;
        return renderer.getListCellRendererComponent
            (_list, vDisplay, index,
             isSelected, cellHasFocus);
    }
    /*ListSelectionListener*************************/
    public void valueChanged(ListSelectionEvent evt) {
        fireValueChanged();
    }
    /*Field*******************************/
    public void setValue(Object v) throws ParseException {
        notFound.clear();
        if (v==null) {
            selectionModel.clearSelection();
        } else if (v instanceof String) {
            selectionModel.setValueIsAdjusting(true);
            try {
                selectionModel.clearSelection();
                String values = (String)v;
                StringTokenizer st = delimiter==null
                    ?new StringTokenizer(values)
                        :new StringTokenizer(values, delimiter);
                while (st.hasMoreTokens()) {
                    String token = st.nextToken();
                    int index = list.indexOf(token);
                    if (index==-1) {
                        notFound.add(token);
                    }  else {
                        selectionModel.addSelectionInterval(index, index);
                    }
                }
            } finally {
                selectionModel.setValueIsAdjusting(false);
            }
        } else {
            throw new ParseException("unknown class: "+v.getClass(), 0);
        }
    }
    public Object getValue() throws ParseException {
        StringBuffer sb = new StringBuffer();
        for (Iterator it=notFound.iterator(); it.hasNext();) {
            String token = (String)it.next();
            sb.append(token);
            sb.append(delimiter);
        }
        Object[] sel = component.getSelectedValues();
        for (int z=0; z<sel.length; z++) {
            sb.append(sel[z].toString());
            sb.append(delimiter);
        }
        int len = sb.length()-delimiter.length();
        if (len<=0)
            return null;
        sb.setLength(len);
        return sb.toString();
    }
    public void setEnabled(boolean _e) {
        component.setEnabled(_e);
    }
    public boolean getEnabled() {
        return component.isEnabled();
    }
}
