/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: MenuSelectField.java,v 1.7 2001/10/30 16:46:46 max Exp $
 *
 */

package make.swing.field;

import java.util.Map;
import java.awt.Dialog;
import java.awt.Component;
import java.awt.Dimension;
import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.text.ParseException;
import javax.swing.JPanel;
import javax.swing.JMenu;
import javax.swing.JButton;
import javax.swing.JPopupMenu;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.SwingConstants;
import javax.swing.plaf.basic.BasicArrowButton;
import make.swing.ButtonManager;

public class MenuSelectField extends DefaultField 
    implements FieldListener {
    protected class MenuAction
        implements ActionListener, MouseListener {
        /***ActionListener************/
        public void actionPerformed(ActionEvent evt) {
            try {
                setValue(evt.getActionCommand());
            } catch (ParseException e) {
                JOptionPane.showMessageDialog(null, e.getLocalizedMessage(),
                                              "Eingabefehler", JOptionPane.ERROR_MESSAGE);
            }
        }
        /***MouseListener*************/
        public void mouseClicked(MouseEvent e) {}
        public void mousePressed(MouseEvent evt) {
            Component source = (Component)evt.getSource();
            Dimension size = source.getSize();
            menu.show(source, 0, size.height);
        }
        public void mouseReleased(MouseEvent evt) {}
        public void mouseEntered(MouseEvent e) {}
        public void mouseExited(MouseEvent e) {}
    }
    /***properties**************************/
    protected JPanel panel = new JPanel(new BorderLayout(), false);
    protected Map map;
    protected Field field;
    protected JButton menuButton;
    protected JPopupMenu menu = new JPopupMenu();
    protected MenuAction menuAction = new MenuAction();
    /***Constructor************************/
    public MenuSelectField(Field _f, Map _map, Object[] _m) {
        map = _map;
        // field
        field = _f;
        field.addFieldListener(this);
        panel.add("Center", field.getComponent());
        // button
        menuButton = new BasicArrowButton(SwingConstants.SOUTH);
        menuButton.addMouseListener(menuAction);
        panel.add("East", menuButton);
        // panel
        setComponent(panel);
        for (int z=0; z<_m.length; z++) {
            JMenuItem mi = createMenuItem(_m[z]);
            if (mi==null)
                menu.addSeparator();
            else
                menu.add(mi);
        }
    }
    /***Internal*************************/
    protected JMenuItem createMenuItem(Object o) {
        if (o instanceof String) {
            String code = (String)o;
            Object caption = map.get(code);
            if (caption==null) caption = code;
            JMenuItem mi = new JMenuItem(caption.toString());
            mi.setActionCommand(code);
            mi.addActionListener(menuAction);
            return mi;
        } else if (o instanceof Object[]) {
            Object[] a = (Object[])o;
            JMenu m = new JMenu((String)a[0]);
            for (int z=1; z<a.length; z++) {
                JMenuItem mi = createMenuItem(a[z]);
                if (mi==null)
                    m.addSeparator();
                else
                    m.add(mi);
            }
            return m;
        } else
            return null;
    }
    /***Field*******************************/
    public void install(ButtonManager bm) {
        super.install(bm);
        field.install(bm);
    }
    public void uninstall(ButtonManager bm) {
        super.uninstall(bm);
        field.uninstall(bm);
    }
    public void setValue(Object v) throws ParseException {
        field.setValue(v);
    }
    public Object getValue() throws ParseException {
        return field.getValue();
    }
    public void setEnabled(boolean _e) {
        menuButton.setEnabled(_e);
        field.setEnabled(_e);
    }
    public boolean getEnabled() {
        return menuButton.isEnabled();
    }
    public void dispose() {
        panel = null;
        map = null;
        field.removeFieldListener(this);
        field.dispose();
        field = null;
        super.dispose();
    }
    /***FieldListener*************************/
    public void valueChanged(FieldEvent evt) {
        fireValueChanged();
    }
    public void focusGained(FieldEvent evt) {
        fireFocusGained();
    }
    public void focusLost(FieldEvent evt) {
        fireFocusLost();
    }
    public void actionPerformed(FieldEvent evt) {
        fireActionPerformed();
    }
}
