/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: RadioField.java,v 1.2 2001/12/18 19:36:47 max Exp $
 *
 */

package make.swing.field;

import java.util.Map;
import java.util.HashMap;
import java.util.Iterator;
import java.text.ParseException;
import javax.swing.Box;
import javax.swing.ButtonGroup;
import javax.swing.ButtonModel;
import javax.swing.JRadioButton;

public class RadioField extends DefaultField {
    /*properties*************/
    protected Box box;
    protected ButtonGroup buttonGroup = new ButtonGroup();
    protected Map valueToModel = new HashMap();
    protected Map modelToValue = new HashMap();
    /*Constructor*************/
    public RadioField(int axis, Object[] values, String[] captions) {
        box = new Box(axis);
        if (captions!=null && captions.length!=values.length)
            throw new IllegalArgumentException
                ("captions.length="+captions.length+
                 " values.length="+values.length);
        for (int z=0; z<values.length; z++) {
            String caption = captions==null ? null : captions[z];
            if (caption==null)
                caption = ""+values[z];
            JRadioButton radioButton = new JRadioButton(caption);
            radioButton.addActionListener(this);
            box.add(radioButton);
            buttonGroup.add(radioButton);
            ButtonModel buttonModel = radioButton.getModel();
            Object value = values[z];
            // 'this' stands for null, because null can't be used
            // as key in hashes... yeah this is a hack
            if (value==null)
                value = this;
            valueToModel.put(value, buttonModel);
            modelToValue.put(buttonModel, value);
        }
        setComponent(box);
    }
    /*Slot*********************************/
    public void setValue(Object v) throws ParseException {
        if (v==null)
            v = this;
        ButtonModel model = (ButtonModel)valueToModel.get(v);
        if (model==null) {
            // clear existing selection
            ButtonModel selectedModel = buttonGroup.getSelection();
            if (selectedModel!=null)
                buttonGroup.setSelected(selectedModel, false);
        } else {
            // set new selection
            buttonGroup.setSelected(model, true);
        }
    }
    public Object getValue() throws ParseException {
        ButtonModel selectedModel = buttonGroup.getSelection();
        Object value = modelToValue.get(selectedModel);
        if (value==this)
            value = null;
        return value;
    }
    public void setEnabled(boolean _e) {
        Iterator it = valueToModel.values().iterator();
        while (it.hasNext()) {
            ButtonModel model = (ButtonModel)it.next();
            model.setEnabled(_e);
        }
    }
    public boolean getEnabled() {
        Iterator it = valueToModel.values().iterator();
        if (!it.hasNext())
            return true;
        ButtonModel firstModel = (ButtonModel)it.next();
        return firstModel.isEnabled();
    }
}
