/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Button.java,v 1.7 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.il;

import java.util.Locale;
import java.text.ParseException;
import java.awt.Component;
import org.w3c.dom.Element;
import javax.swing.JButton;
import make.util.Strings;
import make.xml.DOMUtil;
import make.swing.SwingButton;
import make.swing.ButtonManager;

public class Button extends DefaultInputLink {
    /*properties**************************/
    protected JButton component;
    protected SwingButton button;
    /*Constructor*************************/
    public Button(Element vd, Locale locale) { 
        super(vd, locale);
        String caption = Strings.trim
            (vd.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "caption"));
        char mn = 0;
        if (caption==null) {
            Element cap = DOMUtil.getLocalizedUniqueTagNS
                (vd, InputLinkFactory.XML_NAMESPACE, "caption", locale);
            caption = DOMUtil.getElementString(cap);
            String m = Strings.trim
                (cap.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "mnemonic"));
            if (m!=null)
                mn = m.charAt(0);
        }
        String actionCommand = DOMUtil.getElementParameterNS
            (vd, InputLinkFactory.XML_NAMESPACE, "action", false);
        if (actionCommand==null)
            actionCommand = DOMUtil.getElementStringNS
                (vd, InputLinkFactory.XML_NAMESPACE, "action");
        component = new JButton(caption);
        if (mn>0)
            component.setMnemonic(mn);
        component.setActionCommand(actionCommand);
        button = new SwingButton(component);
    }
    /*Widget***************************/
    public void dispose() {
        component = null;
        button = null;
        super.dispose();
    }
    /*InputLink*************************/
    public void install(ButtonManager bm) {
        super.install(bm);
        bm.installButton(button);
    }
    public void uninstall(ButtonManager bm) {
        bm.uninstallButton(button);
        super.uninstall(bm);
    }
    public Component getComponent() { return component; }
    public void reload() {}
    public void apply() throws ParseException {}
    public void checkInput() throws ParseException {}
}
