/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DefaultInputLink.java,v 1.8 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.il;

import java.util.Locale;
import java.text.ParseException;
import java.awt.Component;
import org.w3c.dom.Element;
import javax.swing.JLabel;
import make.xml.DOMUtil;
import make.swing.ButtonManager;

public abstract class DefaultInputLink 
    implements InputLink {
    /*properties**************************/
    protected JLabel label;
    /*Constructor*************************/
    public DefaultInputLink(Element vd, Locale locale) { 
        if (vd!=null) {
            Element lbl = DOMUtil.getLocalizedUniqueTagNS
                (vd, InputLinkFactory.XML_NAMESPACE, "label", locale);
            if (lbl!=null)
                label = createLabel(lbl);
        }
    }
    public DefaultInputLink() {
        this(null, null);
    }
    /*Internal***************************/
    protected static JLabel createLabel(Element vd) {
        JLabel label = new JLabel(DOMUtil.getElementString(vd));
        String mn = vd.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "mnemonic");
        if (mn!=null && mn.length()>0)
            label.setDisplayedMnemonic(mn.charAt(0));
        return label;
    }
    /*Widget*************************/
    public void setEnabled(boolean _e) {}
    public boolean getEnabled() { return true; }
    public abstract Component getComponent();
    public void dispose() {
        label = null;
    }
    /*InputLink*************************/
    public void install(ButtonManager bm) {}
    public void uninstall(ButtonManager bm) {}
    public Component getLabel() { return label; }
    public abstract void reload();
    public abstract void apply() throws ParseException;
    public abstract void checkInput() throws ParseException;
}
