/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DialogInputLink.java,v 1.8 2002/01/03 12:22:55 max Exp $
 *
 */

package make.swing.il;

import java.util.Enumeration;
import java.util.ResourceBundle;
import java.util.Locale;
import java.awt.Component;
import java.awt.Frame;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.text.ParseException;
import org.w3c.dom.Element;
import javax.swing.JComponent;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JOptionPane;
import javax.swing.Box;
import javax.swing.SwingUtilities;
import javax.swing.BorderFactory;
import make.util.Strings;
import make.util.Resources;
import make.xml.DOMUtil;

public class DialogInputLink extends PanelInputLink
    implements ActionListener {
    /*static********************************/
    private static final ResourceBundle resources
        = Resources.getResourceBundle(DialogInputLink.class.getClassLoader(),
                                      "make.swing.Dialog");
    private static final String[] buttonNames
        = { "ok", /*"apply",*/ "cancel" };
    /*properties**************************/
    protected Element vd;
    protected InputLinkFactory inputLinkFactory;
    protected JButton button;
    protected JDialog dialog;
    protected Frame frame;
    protected Locale locale;
    /*Constructor*************************/
    public DialogInputLink(Element _vd, Locale _locale,
                           InputLinkFactory _ilf) { 
        super(_vd, DOMUtil.getChildElements(DOMUtil.getUniqueTagNS(_vd, InputLinkFactory.XML_NAMESPACE, "children")), _locale, _ilf);
        vd = _vd;
        locale = _locale;
        inputLinkFactory = _ilf;
        // button
        String caption = Strings.trim
            (vd.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "caption"));
        char mn = 0;
        if (caption==null) {
            Element cap = DOMUtil.getLocalizedUniqueTagNS
                (vd, InputLinkFactory.XML_NAMESPACE, "caption", locale);
            if (cap!=null) {
                caption = DOMUtil.getElementString(cap);
                String m = Strings.trim
                    (cap.getAttributeNS(InputLinkFactory.XML_NAMESPACE, "mnemonic"));
                if (m!=null)
                    mn = m.charAt(0);
            }
        }
        button = new JButton(caption);
        if (mn>0)
            button.setMnemonic(mn);
        button.setActionCommand("dlg");
        button.addActionListener(this);
    }
    protected static JDialog createDialog(Frame frame, ActionListener al,
                                          Component component,
                                          Element vd, Locale locale,
                                          InputLinkFactory ilf) {
        // dialog
        String title = DOMUtil.getLocalizedElementParameterNS
            (vd, InputLinkFactory.XML_NAMESPACE, "title", locale, false);
        JDialog dialog = new JDialog(frame, title, true);
        // fields
        dialog.getContentPane().add("Center", component);
        ((JComponent)component).setBorder
            (BorderFactory.createEmptyBorder(0, 0, 3, 0));
        // buttons
        Box box = Box.createHorizontalBox();
        dialog.getContentPane().add("South", box);
        box.add(Box.createHorizontalGlue());
        for (int z=0; z<buttonNames.length; z++) {
            JButton bt = new JButton(resources.getString(buttonNames[z]+".label"));
            bt.setActionCommand(buttonNames[z]);
            bt.addActionListener(al);
            box.add(bt);
            if (z==0)
                dialog.getRootPane().setDefaultButton(bt);
        }
        // borders
        ((JComponent)dialog.getContentPane()).setBorder
            (BorderFactory.createEmptyBorder(5, 5, 5, 5));
        dialog.setResizable(false);
        dialog.pack();
        // return
        return dialog;
    }
    protected boolean applyInput() {
        try {
            super.checkInput();
            super.apply();
            return true;
        } catch (ParseException e) {
            JOptionPane.showMessageDialog
                (frame, e.getLocalizedMessage(), 
                 "Eingabefehler", JOptionPane.ERROR_MESSAGE);
            return false;
        }
    }
    /*Public*************************************/
    public void show() {
        if (dialog==null) {
            Component root = SwingUtilities.getRoot(button);
            frame = root instanceof Frame ? (Frame)root : null;
            dialog = createDialog(frame, this, super.getComponent(),
                                  vd, locale, inputLinkFactory);
            vd = null; inputLinkFactory = null;
        }
        super.reload();
        dialog.show();
    }
    public void hide() {
        dialog.setVisible(false);
    }
    /*ActionListener************************/
    public void actionPerformed(ActionEvent evt) {
        if (evt.getActionCommand().equals("dlg")) {
            show();
        } else if (evt.getActionCommand().equals("ok")) {
            if (applyInput())
                hide();
            else
                super.reload();
        } else if (evt.getActionCommand().equals("apply")) {
            applyInput();
        } else if (evt.getActionCommand().equals("cancel")) {
            super.reload();
            hide();
        }
    }
    /*InputLink*************************/
    public Component getComponent() { return button; }
    public void reload() {}
    public void apply() throws ParseException {}
    public void checkInput() throws ParseException {}
    public void dispose() {
        if (dialog!=null) {
            dialog.dispose();
            dialog = null;
        }
        super.dispose();
    }
    /*CompositeInputLink****************/
    public Enumeration getInputLinks() {
        return new Enumeration() {
                public boolean hasMoreElements() { return false; }
                public Object nextElement() { throw new InternalError(); }
            };
    }
}
