/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FieldInputLink.java,v 1.8 2001/12/20 16:49:08 max Exp $
 *
 */

package make.swing.il;

import java.util.Locale;
import java.text.ParseException;
import java.awt.Component;
import org.w3c.dom.Element;
import make.xml.DOMUtil;
import make.swing.field.Field;
import make.datamodel.slot.Slot;
import make.datamodel.slot.SlotContainer;
import make.swing.ButtonManager;

public class FieldInputLink extends DefaultInputLink {
    /*properties**********************/
    protected Slot slot;
    protected Field field;
    /*Constructor*************************/
    public FieldInputLink(Element vd, Slot _slot, Field _field,
                          Locale locale) { 
        super(vd, locale);
        slot = _slot; field = _field;
        reload();
    }
    public FieldInputLink(Element vd, SlotContainer _sc, Field _field,
                          Locale locale) { 
        super(vd, locale);
        String pathString = DOMUtil.getElementStringNS
            (vd, InputLinkFactory.XML_NAMESPACE, "path", false);
        slot = _sc.getSlot(pathString);
        field = _field;
        reload();
    }
    /*FieldInputLink******************/
    public void setSlot(Slot _slot) {
        slot = _slot;
        reload();
    }
    public void setSlot(Element vd, SlotContainer _sc) {
        String pathString = DOMUtil.getElementStringNS
            (vd, InputLinkFactory.XML_NAMESPACE, "path", false);
        setSlot(_sc.getSlot(pathString));
    }
    public void setField(Field _field) {
        field = _field;
        reload();
    }
    /*Info********************************/
    public Field getField() { 
        return field; 
    }
    public Slot getSlot() { 
        return slot; 
    }
    /*Widget***************************/
    public void install(ButtonManager bm) {
        super.install(bm);
        field.install(bm);
    }
    public void uninstall(ButtonManager bm) {
        field.uninstall(bm);
        super.uninstall(bm);
    }
    public void setEnabled(boolean _e) {
        field.setEnabled(_e);
    }
    public boolean getEnabled() { 
        return field.getEnabled();
    }
    public Component getComponent() { 
        return field.getComponent(); 
    }
    /*InputLink*************************/
    public void reload() {
        if (field==null)
            return;
        try {
            if (slot==null)
                field.setValue(null);
            else {
                Object v;
                try {
                    v = slot.getValue();
                } catch (ParseException e) {
                    v = null;
                }
                try {
                    field.setValue(v);
                } catch (ParseException e) {
                    field.setValue(null);
                }
            }
        } catch (ParseException e) {
        }
    }
    public void apply() throws ParseException {
        if (!getEnabled())
            return;
        if (field!=null && slot!=null)
            slot.setValue(field.getValue());
    }
    public void checkInput() throws ParseException {
        if (!getEnabled())
            return;
        Object ov = null;
        try {
            ov = slot.getValue();
        } catch (ParseException e) {
        }
        slot.setValue(field.getValue());
        try {
            slot.setValue(ov);
        } catch (ParseException e) {
        }
    }
    public void dispose() {
        if (field!=null) {
            field.dispose();
            field = null;
        }
        slot = null;
        super.dispose();
    }
}
