/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DesktopPanelContent.java,v 1.1 2001/10/12 20:01:55 max Exp $
 *
 */

package make.swing.panel;

import java.awt.Frame;
import java.util.Vector;
import java.util.Enumeration;
import java.awt.Component;
import javax.swing.JDesktopPane;
import javax.swing.Action;

/**
 * This PanelContent implementation displays a
 * JDesktopPane.
 */
public class DesktopPanelContent implements PanelContent {
    /*properties****************************/
    protected InterfacePanel interfacePanel;
    protected JDesktopPane desktop = new JDesktopPane();
    protected Vector frames = new Vector();
    protected Action[] actions;
    /*Constructor************************/
    public DesktopPanelContent(InterfacePanel _ip, Action[] _a) {
	desktop.putClientProperty("JDesktopPane.dragMode", "faster");
	interfacePanel = _ip;
	interfacePanel.setContent(this);
	actions = _a;
	if (actions!=null)
	    interfacePanel.getButtonManager().installActions(actions);
    }
    /*DesktopPanelContent********************/
    /**
     * Returns the Frame object this object belongs to
     */
    public Frame getFrame() {
	return interfacePanel.getFrame();
    }
    /**
     * Adds a new internal frame to the desktop
     */
    public void addFrame(InternalFrameInterfacePanel ip) {
	frames.addElement(ip);
	desktop.add(ip.getInternalFrame());
    }
    /**
     * Removes an internal frame from the desktop
     */
    public void removeFrame(InternalFrameInterfacePanel ip) {
	// commented this out due to a bug in Swing:
	//desktop.remove(ip.getInternalFrame());
	frames.removeElement(ip);
    }
    /**
     * Creates a new internal frame and wraps it
     * as an InterfacePanel implementation.
     */
    public InterfacePanel createInterfacePanel() {
	return new InternalFrameInterfacePanel(this);
    }
    /*PanelContent****************************/
    public Component getComponent() {
	return desktop;
    }
    public boolean panelClosing() {
	for (Enumeration enum=frames.elements();
	     enum.hasMoreElements();) {
	    InternalFrameInterfacePanel ip
		= (InternalFrameInterfacePanel)enum.nextElement();
	    PanelContent pc = ip.getContent();
	    if (pc!=null && !pc.panelClosing())
		return false;
	}
	return true;
    }
    public void panelClosed() {
	if (actions!=null) {
	    interfacePanel.getButtonManager().uninstallActions(actions);
	    actions = null;
	}
	for (Enumeration enum=frames.elements();
	     enum.hasMoreElements();) {
	    InternalFrameInterfacePanel ip
		= (InternalFrameInterfacePanel)enum.nextElement();
	    ip.close();
	}
	frames.removeAllElements();
	frames = null;
	desktop = null;
	interfacePanel = null;
    }
}
