/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DialogInterfacePanel.java,v 1.3 2001/12/17 10:14:31 max Exp $
 *
 */

package make.swing.panel;

import java.util.ResourceBundle;
import java.awt.Frame;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import javax.swing.Box;
import javax.swing.JComponent;
import javax.swing.JDialog;
import javax.swing.JButton;
import javax.swing.JMenuBar;
import javax.swing.Action;
import javax.swing.AbstractAction;
import javax.swing.BorderFactory;
import make.util.Debug;
import make.util.Resources;
import make.swing.SwingButton;
import make.swing.ButtonManager;
import make.swing.bt.FrameDescription;

public class DialogInterfacePanel extends AbstractInterfacePanel {
    /*static******************************/
    private static final ResourceBundle resources
        = Resources.getResourceBundle
        (DialogInterfacePanel.class.getClassLoader(),
         "make.swing.Dialog");
    /*properties********************************/
    protected boolean shown = false;
    protected String title, fileName;
    protected JDialog dialog;
    private WindowAdapter closingListener = new WindowAdapter() {
            public void windowClosing(WindowEvent evt) {
                PanelContent content = DialogInterfacePanel.this.getContent();
                if (content==null || content.panelClosing())
                    close();
            }
        };
    /*Constructor**********************************/
    public DialogInterfacePanel(Frame _frame) {
        dialog = new JDialog(_frame, true);
        initialize(_frame, dialog, dialog.getContentPane());
        Component contentPane = dialog.getContentPane();
        if (contentPane instanceof JComponent)
            ((JComponent)contentPane).setBorder(BorderFactory.createEmptyBorder(5,5,5,5));
        getButtonManager().installActions(getActions());
        dialog.setDefaultCloseOperation(dialog.DO_NOTHING_ON_CLOSE);
        dialog.addWindowListener(closingListener);
        if (Debug.LEAK_DEBUG)
            System.err.println("+ DIP "+this);
    }
    protected void finalize() throws Throwable {
        super.finalize();
        if (Debug.LEAK_DEBUG)
            System.err.println("- DIP "+this);
    }
    /*DialogInterfacePanel******************************/
    public void setButtonsClose() {
        // box
        Box box = Box.createHorizontalBox();
        box.add(Box.createHorizontalGlue());
        // create buttons
        JButton close = new JButton(resources.getString("close.label"));
        close.setActionCommand("close-frame");
        box.add(close);
        // register in our ButtonManager
        ButtonManager bm = getButtonManager();
        bm.installButton(new SwingButton(close));
        // add to the dialog
        setSouth(box);
        dialog.getRootPane().setDefaultButton(close);
    }
    public void setButtonsOkCancel() {
        // box
        Box box = Box.createHorizontalBox();
        box.add(Box.createHorizontalGlue());
        // create buttons
        JButton ok = new JButton(resources.getString("ok.label"));
        JButton cancel = new JButton(resources.getString("cancel.label"));
        ok.setActionCommand("ok");
        cancel.setActionCommand("cancel");
        box.add(ok);
        box.add(cancel);
        // register in our ButtonManager
        ButtonManager bm = getButtonManager();
        bm.installButton(new SwingButton(ok));
        bm.installButton(new SwingButton(cancel));
        // add to the dialog
        setSouth(box);
        dialog.getRootPane().setDefaultButton(ok);
    }
    public void show() {
        beforeShow();
        setVisible(true);
    }
    /*Internal***************************************/
    protected void updateTitle() {
        if (fileName==null)
            dialog.setTitle(title);
        else if (title==null)
            dialog.setTitle(fileName);
        else
            dialog.setTitle(fileName+" - "+title);
    }
    /*AbstractInterfacePanel******************************/
    protected void setMenuBar(JMenuBar mb) {
        dialog.setJMenuBar(mb);
    }
    /*InterfacePanel******************************/
    public void addFrameDescription(FrameDescription fd) {
        super.addFrameDescription(fd);
        String t = fd.getTitle();
        if (t!=null) {
            title = t;
            updateTitle();
        }
    }
    public void setTitle(String s) { 
        fileName = s; updateTitle();
    }
    public void close() {
        dialog.removeWindowListener(closingListener);
        dialog.dispose();
        dialog = null;
        getButtonManager().uninstallActions(getActions());
        super.close();
    }
    /*Actions*******************************************/
    protected Action[] getActions() {
        return defaultActions;
    }
    protected Action[] defaultActions = {
        new CloseFrameAction(),
    };
    class CloseFrameAction extends AbstractAction {
        CloseFrameAction() { super("close-frame"); }
        public void actionPerformed(ActionEvent e) {
            PanelContent content = DialogInterfacePanel.this.getContent();
            if (content==null || content.panelClosing())
                close();
        }
    }
}
