/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: FrameInterfacePanel.java,v 1.1 2001/10/12 20:01:55 max Exp $
 *
 */

package make.swing.panel;

import java.awt.Frame;
import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.WindowEvent;
import java.awt.event.WindowAdapter;
import javax.swing.JFrame;
import javax.swing.JMenuBar;
import javax.swing.Action;
import javax.swing.AbstractAction;
import make.util.Debug;
import make.swing.bt.FrameDescription;

/**
 * This InterfacePanel implementation creates
 * a javax.swing.JFrame object.
 */
public class FrameInterfacePanel extends AbstractInterfacePanel {
    /*properties********************************/
    protected String title, fileName;
    protected JFrame frame = new JFrame();
    private WindowAdapter closingListener = new WindowAdapter() {
	public void windowClosing(WindowEvent evt) {
	    PanelContent content = FrameInterfacePanel.this.getContent();
	    if (content==null || content.panelClosing())
		close();
	}
    };
    /*Constructor**********************************/
    public FrameInterfacePanel() {
	initialize(frame, frame, frame.getContentPane());
	getButtonManager().installActions(getActions());
	frame.setDefaultCloseOperation(frame.DO_NOTHING_ON_CLOSE);
	frame.addWindowListener(closingListener);
	if (Debug.LEAK_DEBUG)
	    System.err.println("+fip "+this);
    }
    protected void finalize() throws Throwable {
	super.finalize();
	if (Debug.LEAK_DEBUG)
	    System.err.println("-fip "+this);
    }
    /*Internal***************************************/
    protected void updateTitle() {
	if (fileName==null)
	    frame.setTitle(title);
	else if (title==null)
	    frame.setTitle(fileName);
	else
	    frame.setTitle(fileName+" - "+title);
    }
    /*AbstractInterfacePanel******************************/
    protected void setMenuBar(JMenuBar mb) {
	frame.setJMenuBar(mb);
	frame.validate();
    }
    /*InterfacePanel******************************/
    public void addFrameDescription(FrameDescription fd) {
	super.addFrameDescription(fd);
	String t = fd.getTitle();
	if (t!=null) {
	    title = t;
	    updateTitle();
	}
    }
    public void setTitle(String s) { 
	fileName = s; updateTitle();
    }
    public void setVisible(boolean _visible) {
	super.setVisible(_visible);
	if (_visible)
	    frame.toFront();
    }
    public void close() {
	frame.removeWindowListener(closingListener);
	frame.dispose();
	getButtonManager().uninstallActions(getActions());
	super.close();
    }
    /*Actions*******************************************/
    protected Action[] getActions() {
	return defaultActions;
    }
    protected final Action[] defaultActions = {
	new CloseFrameAction(),
	new ShowToolBarAction(),
    };
    class CloseFrameAction extends AbstractAction {
	CloseFrameAction() { super("close-frame"); }
        public void actionPerformed(ActionEvent e) {
	    PanelContent content = FrameInterfacePanel.this.getContent();
	    if (content==null || content.panelClosing())
		close();
	}
    }
    class ShowToolBarAction extends AbstractAction {
	ShowToolBarAction() { super("show-toolbar"); }
        public void actionPerformed(ActionEvent e) {
	    Component c = getToolBar();
	    if (c!=null)
		c.setVisible(!c.isVisible());
	}
    }
}
