/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: InterfacePanel.java,v 1.1 2001/10/12 20:01:55 max Exp $
 *
 */

package make.swing.panel;

import java.awt.Frame;
import make.swing.ButtonManager;
import make.swing.bt.FrameDescription;
import make.swing.bt.ButtonContainer;

/**
 * An InterfacePanel is an area on the screen where the application can 
 * display user interfaces. This can be a modal dialog, a frame or even a 
 * rectangular area within a frame. An InterfacePanel may provide some basic
 * UI functionality, e.g. a menu bar, a ButtonManager, etc.
 */
public interface InterfacePanel { 
    /**
     * Sets the content of this InterfacePanel and shows it. This method may 
     * be used  multiple times as an InterfacePanel is able to be reused. The
     * parameter may be null, in this case, blank screen is displayed, 
     * or it is hidden (if possible).
     */
    void setContent(PanelContent c);
    /**
     * Adds an FrameDescription object to this object. This may contain
     * things like menu bars or tool bars.
     */
    void addFrameDescription(FrameDescription fd);
    /**
     * Removes the given FrameDescription object.
     */
    void removeFrameDescription(FrameDescription fd);
    /**
     * Returns the associated ButtonContainer. It contains all buttons
     * which came along with the FrameDescription objects.
     */
    ButtonContainer getButtonContainer();
    /**
     * Returns the associated ButtonManager. All buttons are already 
     * registered.
     */
    ButtonManager getButtonManager();
    /**
     * Sets the title if it is possible.
     */
    void setTitle(String s);
    /**
     * Finds a parent that is a Frame and should be parent of new dialogs.
     */
    Frame getFrame();
    /**
     * Shows or hides the object if this is possible.
     */
    void setVisible(boolean _visible);
    /**
     * Closes and destructs the object.
     */
    void close();
}
