/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ContainerChange.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text;

import make.util.Interval;
import make.util.InsertInterval;
import make.util.RemoveInterval;
import make.util.Debug;

public class ContainerChange {
    /***properties*******************************/
    protected Interval changed = new Interval();
    protected Interval added = new InsertInterval();
    protected Interval removed = new RemoveInterval();
    protected Element element;
    /***Constructor********************************/
    public ContainerChange(Element _el) {
	element = _el;
    }
    /***Grow************************************/
    public void childChanged(int i) { 
	//System.err.println("CHANGED "+element+"["+i+"]");
	if (Debug.DEBUG && (i<0 || i>=element.getElementCount())) {
	    System.err.println("FATAL ERROR: wrong changed index: "+i);
	    System.err.println("this = "+this);
	    System.err.println("elementCount = "+element.getElementCount());
	    throw new InternalError();
	}
	changed.include(i);
    }
    public void childAdded(int i) {
	//System.err.println("ADDED "+element+"["+i+"]");
	added.include(i); 
	removed.inserted(i);
	changed.inserted(i);
    }
    public void childRemoved(int i) { 
	//System.err.println("REMOVED "+element+"["+i+"]");
	changed.removed(i);
	if (i>=added.getFirst())
	    if (i>added.getLast()) {
		i -= added.getCount();
		removed.include(i);
	    } else {
		added.removed(i);
	    }
	else {
	    removed.include(i);
	    added.removed(i);
	}
    }
    /***Info*************************************/
    public boolean isTouched(int i) { 
	return changed.contains(i) || added.contains(i);
    }
    public Element getElement() { return element; }
    public Interval getChanged() { return changed; }
    public Interval getAdded() { return added; }
    public Interval getRemoved() { return removed; }
    public void dump() {
	if (Debug.DEBUG) {
	    System.err.println("ContainerChange "+this);
	    System.err.println(" - changed = "+getChanged());
	    System.err.println(" - added = "+getAdded());
	    System.err.println(" - removed = "+getRemoved());
	}
    }
    public String toString() {
	return "["+super.toString()+": el="+element+" changed="+getChanged()+" added="+getAdded()+" removed="+getRemoved()+"]";
    }
}
