/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ExtendedContainerChange.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text;

import java.util.Vector;
import java.util.Enumeration;
import make.util.Debug;
import make.util.Interval;
import make.util.RemoveInterval;

public class ExtendedContainerChange extends ContainerChange {
    /***CONST***********************************/
    protected static final Byte CHANGED = new Byte((byte)1);
    protected static final Byte ADDED = new Byte((byte)2);
    /***properties*******************************/
    protected int base = -1;
    protected Vector changes = new Vector();
    protected Vector removes = new Vector();
    protected boolean translated = false;
    /***Constructor********************************/
    public ExtendedContainerChange(Element _el) {
	super(_el);
    }
    /***Grow************************************/
    public void childChanged(int i) {
	//System.err.println("chg "+getElement()+" i="+i);
	if (Debug.DEBUG && translated)
	    throw new InternalError("too late");
	if (base==-1) {
	    base = i;
	    changes.addElement(CHANGED);
	} else if (i<base) {
	    if (i<(base-1))
		for (int z=i+1; z<base; z++)
		    changes.insertElementAt(null, 0);
	    base = i;
	    changes.insertElementAt(CHANGED, 0);
	} else if (i>=(base+changes.size())) {
	    if (i>(base+changes.size()))
		for (int z=i-changes.size()-base; z>0; z--)
		    changes.addElement(null);
	    changes.addElement(CHANGED);
	} else {
	    if (changes.elementAt(i-base)==null)
		changes.setElementAt(CHANGED, i-base);
	}
    }
    public void childAdded(int i) { 
	//System.err.println("add "+getElement()+" i="+i);
	if (Debug.DEBUG && translated)
	    throw new InternalError("too late");
	if (base==-1) {
	    base = i;
	    changes.addElement(ADDED);
	} else if (i<base) {
	    if (i<(base-1))
		for (int z=i; z<base; z++)
		    changes.insertElementAt(null, 0);
	    base = i;
	    changes.insertElementAt(ADDED, 0);
	} else if (i>=(base+changes.size())) {
	    if (i>(base+changes.size()))
		for (int z=i-changes.size()-base; z>0; z--)
		    changes.addElement(null);
	    changes.addElement(ADDED);
	} else {
	    changes.insertElementAt(ADDED, i-base);
	}
    }
    public void childRemoved(int i) { 
	if (Debug.DEBUG && translated)
	    throw new InternalError("too late");
	boolean ad = false;
	if (i<(base+changes.size())) {
	    if (i>=base) {
		Object chg = changes.elementAt(i-base);
		changes.removeElementAt(i-base);
		if (chg==ADDED)
		    ad = true;
		else
		    if (i==base) base++;
		final int last = i-base-1;
		for (int z=0; z<=last; z++) 
		    if (changes.elementAt(z)==ADDED)
			i--;
	    } else
		    base--;
	} else {
	    final int last = Math.min(changes.size(), i-base)-1;
	    for (int z=0; z<=last; z++)
		if (changes.elementAt(z)==ADDED)
		    i--;
	}
	int z;
	Interval in = null;
	for (z=0; z<removes.size(); z++) {
	    in = (Interval)removes.elementAt(z);
	    if (i>=(in.getFirst()-1))
		break;
	}
	if (!ad) {
	    if (in==null || i>in.getFirst()) {
		if (in==null) z--;
		in = new RemoveInterval();
		removes.insertElementAt(in, ++z);
	    }
	    in.include(i);
	}
	if (++z<removes.size()) {
	    Interval in2 = (Interval)removes.elementAt(z++);
	    in2.removed(i);
	    if (in!=null && in2.getFirst()==in.getFirst()) {
		in.include(in2);
		removes.removeElementAt(--z);
	    }
	}
	for (; z<removes.size(); z++)
	    ((Interval)removes.elementAt(z)).removed(i);
    }
    /***Internal**********************************/
    protected synchronized void syncIntervals() {
	if (translated) return;
	if (base!=-1)
	    for (Enumeration enum=changes.elements(); enum.hasMoreElements(); base++) {
		Byte t = (Byte)enum.nextElement();
		if (t==CHANGED)
		    super.childChanged(base);
		else if (t==ADDED)
		    super.childAdded(base);
	    }
	if (Debug.DEBUG && removes.size()>1) {
	    System.err.println("FATAL ERROR: Removes fragmented for "+getElement());
	    for (Enumeration enum=removes.elements(); enum.hasMoreElements();) {
		Interval i = (Interval)enum.nextElement();
		System.err.println("Interval: "+i);
	    }
	    throw new InternalError("Removes fragmented");
	}
	if (removes.size()>0) {
	    removed = (Interval)removes.elementAt(0);
	}
	/*System.err.println("=====ExtendedChange for "+getElement());
	  System.err.println("removed: "+removed);
	  System.err.println("added: "+added);
	  System.err.println("changed: "+changed);
	  System.err.println("-----------------------------------");*/
	changes = null;
	removes = null;
	translated = true;
    }
    /***Info****************************************/
    public boolean isTouched(int i) {
	return translated
	    ?super.isTouched(i)
	    :i>=base && i<(base+changes.size()) && changes.elementAt(i-base)!=null;
    }
    public Interval getChanged() { syncIntervals(); return changed; }
    public Interval getAdded() { syncIntervals(); return added; }
    public Interval getRemoved() { syncIntervals(); return removed; }
}
