/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: BrokenBoxView.java,v 1.4 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import make.swing.text.Element;

public class BrokenBoxView extends BoxView {
    /***properties********************************/
    protected BoxView original;
    protected int axis;
    /***Constructor*****************************/
    public BrokenBoxView(BoxView _o, int axis) {
	super(_o.getElement(), axis);
	original = _o;
	minorCursorWrap = false;
    }
    /***CompositeView******************************/
    protected void loadChildren(ViewFactory f) {}
    protected int getViewIndexAtPosition(int pos) {
	if (pos<getStartOffset() || pos>getEndOffset())
	    return -1;
	final int n = getViewCount();
	for (int z=0; z<n; z++) {
	    View v = getView(z);
	    final int p0 = v.getStartOffset();
	    final int p1 = v.getEndOffset();
	    if ((pos>=p0) && (pos<p1))
		return z;
	}
	if (pos==getEndOffset())
	    return n-1;
	return -1;
    }
    /***View****************************************/
    public int getStartOffset() { return getView(0).getStartOffset(); }
    public int getEndOffset() { return getView(getViewCount()-1).getEndOffset(); }
    public View createFragment(int p0, int p1) {
	return original.createFragment(p0, p1);
    }
    public int getBreakWeight(int axis, int offset, float pos, float len) {
	return original.getBreakWeight(axis, offset, pos, len);
    }
    public View breakView(int axis, int offset, float pos, float len) {
	return original.breakView(axis, offset, pos, len);
    }
}
