/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ComponentView.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import java.awt.Dimension;
import java.awt.Component;
import java.awt.Rectangle;
import java.awt.Shape;
import java.awt.Graphics;
import javax.swing.text.BadLocationException;
import make.swing.text.Element;
import make.swing.text.DocumentEvent;

public abstract class ComponentView extends View {
    /***properties***************************/
    protected Component component;
    /***Constructor****************************/
    public ComponentView(Element _e) {
	super(_e);
    }
    /***ComponentView**************************/
    protected abstract Component loadComponent();
    protected void sync() {
	if (component==null)
	    component = loadComponent();
    }
    /***View*******************************/
    public void documentChanged(DocumentEvent evt, Shape a, ViewFactory vf) {
	component = null;
    }
    public float getPreferredSpan(int axis) {
	sync();
	Dimension d = component.getPreferredSize();
	return axis==X_AXIS ? d.width : d.height;
    }    
    public float getMinimumSpan(int axis) {
	sync();
	Dimension d = component.getMinimumSize();
	return axis==X_AXIS ? d.width : d.height;
    }    
    public float getMaximumSpan(int axis) {
	sync();
	Dimension d = component.getMaximumSize();
	return axis==X_AXIS ? d.width : d.height;
    }    
    public void paint(Graphics g, Shape allocation) {
	sync();
	Rectangle r = allocation instanceof Rectangle
	    ?((Rectangle)allocation)
	    :allocation.getBounds();
	component.setBounds(r);
	component.setVisible(true);
    }
    public float getAlignment(int axis) {
	sync();
	return axis==X_AXIS
	    ?component.getAlignmentX()
	    :component.getAlignmentY();
    }
    public Shape modelToView(int pos, Shape a)
	throws BadLocationException {
	sync();
	Rectangle r = a.getBounds();
	if (pos>getStartOffset())
	    r.x += r.width;
	r.width = 0;
	return r;
    }
    public int viewToModel(float x, float y, Shape allocation) {
	sync();
	Rectangle r = allocation instanceof Rectangle
	    ?((Rectangle)allocation)
	    :allocation.getBounds();
	return x<=(r.x+r.width/2)
	    ?getStartOffset()
	    :getEndOffset();
    }
}
