/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: LabelFragment.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.swing.text.view;

import java.awt.Shape;
import javax.swing.text.BadLocationException;
import make.util.Debug;
import make.swing.text.DocumentEvent;

public class LabelFragment extends LabelView {
    /***properties******************************/
    protected LabelView original;
    protected short offset, length;
    /***Contructor****************************************/
    public LabelFragment(LabelView _o, int p0, int p1) {
	super(_o.getElement());
	original = _o;
	if (Debug.DEBUG) {
	    if (p0<original.getStartOffset())
		throw new InternalError("wrong startOffset in labelFragment");
	    if (p1>original.getEndOffset())
		throw new InternalError("wrong endOffset in labelFragment");
	    if (p0>p1)
		throw new InternalError("startOffset>endOffset in labelFragment");
	}
	offset = (short)(p0 - original.getStartOffset());
	length = (short)(p1 - p0);
	style = original.getStyle();
	styleMaster = false;
    }
    /***LabelView**********************************************/
    protected void loadText() {
	text.offset = offset;
	text.count = length;
	// TODO: remove workaround
	if (text.offset>text.array.length) {
	    if (Debug.DEBUG)
		System.err.println("WARNING: workaround labelFragment#1");
	    text.offset = text.array.length;
	}
	if ((text.offset+text.count)>text.array.length) {
	    if (Debug.DEBUG)
		System.err.println("WARNING: workaround labelFragment#2 len="+text.array.length+" offs="+text.offset+" count="+text.count);
	    text.count = text.array.length-text.offset;
	}
    }
    protected void loadTextFromElement() {
	original.loadTextFromElement();
	text = original.getText();
    }
    public int getNextVisualPositionFrom(int pos, int direction) 
	throws BadLocationException {
	int res = super.getNextVisualPositionFrom(pos, direction);
	if (res==getEndOffset() && res<original.getEndOffset())
	    res--;
	return res;
    }
    /***View**********************************************/
    public int getStartOffset() { 
	return original.getStartOffset() + offset; 
    }
    public int getEndOffset() { 
	return original.getStartOffset() + offset + length; 
    }
    public void changedUpdate(DocumentEvent e, Shape a, ViewFactory f) {
	throw new InternalError();
    }
    public View breakView(int axis, int offset, float pos, float len) {
	return original.breakView(axis, offset, pos, len);
    }
}
