/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ByteMap.java,v 1.6 2001/08/20 09:23:39 max Exp $
 *
 */

package make.util;

/**
 * ByteMap is an object that maps byte values to strings and back.
 * Currently it is not optimized for big maps, but it's a nice tool
 * if you want to map database columns or XML attributes to values.
 */
public class ByteMap {
    /*properties***********************************/
    protected byte[] bytes;
    protected String[] strings;
    /*Constructor***********************************/
    /**
     * Initializes the ByteMap with two arrays. 
     * Both arrays have to be of the same length.
     */
    public ByteMap(byte[] _b, String[] _s) {
	bytes = _b; strings = _s;
	if (Debug.DEBUG && bytes.length!=strings.length)
	    throw new InternalError("wrong array size");
    }
    /*Map******************************************/
    /**
     * Maps the specified String to a byte.
     */
    public byte map(String s)
	throws IllegalArgumentException {
	for (int z=0; z<strings.length; z++) {
	    if (strings[z].equals(s))
		return bytes[z];
	}
	throw new IllegalArgumentException(s);
    }
    /**
     * Maps the specified byte to a String.
     */
    public String map(byte b) 
	throws IllegalArgumentException {
	for (int z=0; z<bytes.length; z++)
	    if (bytes[z]==b)
		return strings[z];
	throw new IllegalArgumentException(""+b);
    }
}
