/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DelayedTrigger.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.util;

import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;

/**
 * DelayedTrigger is an adapter for an ActionListener object
 * that will perform an action after a specified delay.
 */
public class DelayedTrigger implements Runnable {
    /*properties***********************/
    protected long delay;
    protected Thread thread;
    protected boolean inAction = false;
    protected ActionListener listener;
    protected ActionEvent event;
    /*Constructor**********************/
    public DelayedTrigger(long _d, ActionListener _l, ActionEvent _e) {
	delay = _d; listener = _l; event = _e;
    }
    /*Runnable************************/
    public void run() {
	try {
	    if (Debug.DEBUG && inAction)
		throw new InternalError();
	    while (listener!=null) {
		try {
		    Thread.sleep(delay);
		    try {
			inAction = true;
			listener.actionPerformed(event);
		    } catch (Exception e) {
			System.err.println("Unexpected exception while action:");
			e.printStackTrace(System.err);
		    } finally {
			inAction = false;
		    }
		    return;
		} catch (InterruptedException e) {
		}
	    }
	} finally {
	    thread = null;
	}
    }
    /*Public*************************/
    public synchronized void start() {
	if (thread!=null)
	    try {
		thread.join();
	    } catch (InterruptedException e) {
	    }
	thread = new Thread(this);
	thread.setDaemon(true);
	thread.start();
    }
    public synchronized void restart() {
	if (thread==null) {
	    thread = new Thread(this);
	    thread.setDaemon(true);
	    thread.start();
	} else {
	    if (inAction)
		start();
	    else
		thread.interrupt();
	} 
    }
    public synchronized void stop() {
	if (thread!=null) {
	    listener = null;
	    thread.interrupt();
	}
    }
}
