/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Interval.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.util;

public class Interval {
    /***properties*******************************/
    protected int first=Integer.MAX_VALUE, last=Integer.MIN_VALUE;
    /***Constructor******************************/
    public Interval() {}
    public Interval(int _f) { first = last = _f; }
    public Interval(int _f, int _l) { first = _f; last = _l; }
    /***Info***************************************/
    public boolean isValid() { return first<=last; }
    public final int getFirst() { return first; }
    public final int getLast() { return last; }
    public final int getCount() { return last-first+1; }
    public final boolean contains(int i) {
	return i>=first && i<=last;
    }
    public final boolean contains(Interval i) {
	return contains(i.getFirst()) && contains(i.getLast());
    }
    public final boolean intersects(Interval i) {
	return contains(i.getFirst()) || contains(i.getLast());
    }
    public final void setEmpty() { first=Integer.MAX_VALUE; last=Integer.MIN_VALUE; }
    public String toString() { return "["+first+"|"+last+"]"; }
    /***Grow****************************************/
    public void removed(int i) {
	if (isValid()) {
	    if (first>i) first--;
	    if (last>=i) last--;
	    if (!isValid()) setEmpty();
	}
    }
    public void inserted(int i) {
	if (isValid()) {
	    if (first>=i) first++;
	    if (last>=i) last++;
	}
    }
    public void include(int i) {
	if (i<first) first = i;
	if (i>last) last = i;
    }
    public void include(Interval i) {
	include(i.getFirst());
	include(i.getLast());
    }
}
