/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: LocalizedString.java,v 1.2 2001/12/27 06:36:57 max Exp $
 *
 */

package make.util;

import java.util.Collections;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Locale;

public final class LocalizedString {
    /*properties************************/
    private Map instances;

    /*Constructor*************************/
    private LocalizedString(Map _instances) {
        instances = _instances;
    }
    public LocalizedString(Locale locale, String string) {
        if (string==null)
            throw new NullPointerException();
        instances = new HashMap();
        if (string!=null)
            instances.put(locale, string);
    }
    public LocalizedString(String string) {
        this(null, string);
    }

    public static LocalizedString load(Map _map) {
        if (_map.size()==0)
            return null;
        // check and copy map
        Map instances = new HashMap();
        Iterator it = _map.entrySet().iterator();
        while (it.hasNext()) {
            Map.Entry entry = (Map.Entry)it.next();
            Locale locale = (Locale)entry.getKey();
            String string = (String)entry.getValue();
            instances.put(locale, string);
        }
        return new LocalizedString(instances);
    }

    /*LocalizedString*********************/
    public Set locales() {
        return Collections.unmodifiableSet(instances.keySet());
    }
    public String get(Locale locale) {
        String string = (String)instances.get(locale);
        if (string!=null)
            return string;
        if (locale!=null && locale.getVariant().length()>0) {
            Locale locale2 = new Locale(locale.getLanguage(), locale.getCountry());
            String string2 = (String)instances.get(locale2);
            if (string2!=null)
                return string2;
        }
        if (locale!=null && locale.getCountry().length()>0) {
            Locale locale2 = new Locale(locale.getLanguage(), "");
            String string2 = (String)instances.get(locale2);
            if (string2!=null)
                return string2;
        }
        String string2 = (String)instances.get(null);
        if (string2!=null)
            return string2;
        return (String)instances.values().iterator().next();
    }
    public LocalizedString put(Locale locale, String string) {
        if (string==null)
            throw new NullPointerException();
        Map newInstances = new HashMap();
        newInstances.putAll(instances);
        newInstances.put(locale, string);
        return new LocalizedString(newInstances);
    }
    public LocalizedString remove(Locale locale) {
        if (!instances.containsKey(locale))
            return this;
        if (instances.size()<=1)
            return null;
        Map newInstances = new HashMap();
        newInstances.putAll(instances);
        newInstances.remove(locale);
        return new LocalizedString(newInstances);
    }

    /*Object*****************************/
    public String toString() {
        return get(Locale.getDefault());
    }
}
