/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: Resources.java,v 1.1 2001/12/17 10:13:57 max Exp $
 *
 */

package make.util;

import java.util.Map;
import java.util.HashMap;
import java.util.Locale;
import java.util.ResourceBundle;
import java.util.PropertyResourceBundle;
import java.io.IOException;
import java.io.InputStream;

public abstract class Resources {
    /*properties***********************/
    protected static Locale locale = Locale.getDefault();
    protected static String localeSuffix;
    protected static Map resourceBundles = new HashMap();

    /*Properties*****************************/
    public static Locale getLocale() {
        return locale;
    }
    public static void setLocale(Locale _locale) {
        resourceBundles.clear();
        locale = _locale;
        localeSuffix = null;
    }
    public static void setLocaleSuffix(String _sfx) {
        resourceBundles.clear();
        localeSuffix = _sfx;
    }

    /*ResourceBundle************************/
    public static InputStream getResourceAsStream(ClassLoader classLoader,
                                                  String name, String ext) {
        name = name.replace('.', '/');
        // check for suffix
        if (localeSuffix!=null) {
            InputStream is = classLoader.getResourceAsStream(name+localeSuffix+"."+ext);
            if (is!=null)
                return is;
        }
        // check for locale
        if (locale!=null) {
            String language = locale.getLanguage();
            //String country = locale.getCountry();
            //String variant = locale.getVariant();
            String url = name+"_"+language+"."+ext;
            InputStream is = classLoader.getResourceAsStream(name+"_"+language+"."+ext);
            if (is!=null)
                return is;
        }
        // not found
        return null;
    }
    public static ResourceBundle getResourceBundle(ClassLoader classLoader,
                                                   String name) {
        // check cache
        // NOTE: this cache does not check the class loader;
        //       it assumes that there is not more than one
        //       bundle with the same name in different class loaders
        ResourceBundle cachedBundle
            = (ResourceBundle)resourceBundles.get(name);
        if (cachedBundle!=null)
            return cachedBundle;

        InputStream is = getResourceAsStream(classLoader, name, "properties");
        if (is==null)
            return null;

        try {
            ResourceBundle bundle = new PropertyResourceBundle(is);
            resourceBundles.put(name, bundle);
            return bundle;
        } catch (IOException e) {
            Debug.report(e, "while loading ResourceBundle "+name);
            return null;
        }
    }
}
