/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: ConfigPath.java,v 1.9 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import java.io.InputStream;
import java.io.Reader;
import java.io.InputStreamReader;
import java.util.Hashtable;
import java.net.URL;
import org.w3c.dom.Element;
import org.w3c.dom.Document;
import org.xml.sax.EntityResolver;
import make.module.ResourceLoader;

/**
 * ConfigPath is an object that can load resources
 * or sub-ConfigPath objects.
 */
public class ConfigPath {
    /*properties**********************/
    private ResourceLoader resourceLoader;
    private String path;
    private EntityResolver entityResolver;
    private Hashtable cache = new Hashtable();
    /*Constructor************************/
    public ConfigPath(ResourceLoader _rl, String _p, EntityResolver _er) {
	resourceLoader = _rl; path = _p; entityResolver = _er;
	if (path!=null && path.endsWith("/"))
	    path = path.substring(0, path.length()-1);
    }
    /*ConfigPath*****************************/
    public ConfigPath getPath(String sub) {
	if (path==null)
	    return this;
	return new ConfigPath(resourceLoader, path+"/"+sub, entityResolver);
    }
    public URL getURL(String sub) {
	if (path==null)
	    return null;
	try {
	    return resourceLoader.getResource(path+"/"+sub);
	} catch (Exception e) {
	    System.err.println("while getting config: "+sub);
	    e.printStackTrace();
	    return null;
	}
    }
    public InputStream open(String p) {
	if (path==null)
	    return null;
	try {
	    return resourceLoader.getResourceAsStream(path+"/"+p);
	} catch (Exception e) {
	    System.err.println("while opening config: "+p);
	    e.printStackTrace();
	    return null;
	}
    }
    public Reader read(String p) {
	try {
	    InputStream is = open(p);
	    return is==null
		?null
		:new InputStreamReader(is);
	} catch (Exception e) {
	    System.err.println("while reading config: "+p);
	    e.printStackTrace();
	    return null;
	}
    }
    public Element parse(String p) {
	try {
	    InputStream is = open(p);
	    if (is==null)
		return null;
	    Document doc = DOMUtil.parse(is, entityResolver);
	    if (doc==null)
		return null;
	    return doc.getDocumentElement();
	} catch (Exception e) {
	    System.err.println("while parsing config: "+p);
	    e.printStackTrace();
	    return null;
	}
    }
    public Object getDescription(String p) {
	Object n = cache.get(p);
	if (n==null) {
	    n = parse(p+".xml");
	    if (n!=null && p.indexOf('?')==-1)
		putDescription(p, n);
	}
	if (n instanceof Element) {
	    Element el = (Element)n;
	    if (el.getTagName().equals("redirect")) {
		n = getDescription(el.getAttribute("uri"));
		if (n!=null && p.indexOf('?')!=-1)
		    putDescription(p, n);
	    }
	}
	return n;
    }
    public void putDescription(String p, Object o) {
	cache.put(p, o);
    }
}
