/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DOMWriterFormat.java,v 1.3 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import org.w3c.dom.Element;

/**
 * This class gives a DOMWriter object some hints about
 * how to format an XML file in plain text so it looks
 * nice and readable in a plain text editor.
 * As long as you don't mark an element as "preformatted",
 * DOMWriter does not guarantee any format.
 */
public interface DOMWriterFormat {
    /**
     * tells whether the given element contains preformatted text,
     * i.e. if its whitespace will be fully preserved
     */
    boolean isPreformatted(Element el);
    /**
     * flowing elements will be integrated into the flowing text.
     * Other elements would begin in a new line. This may be useful
     * for text formats like emphasized or hyperlinks.
     */
    boolean isFlowing(Element el);
    boolean getPreserveInnerSpace(Element el);
    boolean getPreserveOuterSpace(Element el);
}
