/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DefaultSchemaManager.java,v 1.2 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import java.util.Enumeration;
import java.util.Hashtable;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import make.util.Debug;

/**
 * Default implementation of SchemaManager.
 */
public class DefaultSchemaManager implements SchemaManager {
    /*properties****************************/
    protected Hashtable schemas = new Hashtable();
    /*SchemaManager***********************/
    public Enumeration getSchemaNames() {
	return schemas.keys();
    }
    public String getSchemaName(Document doc) {
	Element root = doc.getDocumentElement();
	if (root==null)
	    return null;
	return root.getTagName();
    }
    public DocumentType getSchema(String name) {
	return (DocumentType)schemas.get(name);
    }
    public void registerSchema(DocumentType dt) {
	String name = dt.getName();
	Object oldValue = schemas.put(name, dt);
	if (Debug.DEBUG && oldValue!=null) {
	    System.err.println("ERROR: schema not overwritten: "+oldValue);
	    schemas.put(name, oldValue);
	}
    }
    public void unregisterSchema(DocumentType dt) {
	String name = dt.getName();
	Object oldValue = schemas.remove(name);
	if (Debug.DEBUG && oldValue!=dt) {
	    System.err.println("ERROR: schema not in manager: "+dt);
	    if (oldValue!=null)
		schemas.put(name, oldValue);
	}
    }
}
