/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: SchemaManager.java,v 1.2 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import java.util.Enumeration;
import org.w3c.dom.Document;

/**
 * SchemaManager manages a collection of XML schemas.
 */
public interface SchemaManager {
    /**
     * Returns a list of all available schema names.
     */
    Enumeration getSchemaNames();
    /**
     * Returns the schema for the specified document.
     * This does not guarantee that getSchema finds a fitting
     * DocumentType object for the returned schema name.
     */
    String getSchemaName(Document doc);
    /**
     * Loads a schema description.
     */
    DocumentType getSchema(String name);
    /**
     * Registers a new schema.
     */
    void registerSchema(DocumentType dt);
    /**
     * Unregisters an existing schema.
     */
    void unregisterSchema(DocumentType dt);
}
