/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: StylesheetManager.java,v 1.9 2001/08/20 09:23:39 max Exp $
 *
 */

package make.xml;

import java.io.InputStream;
import java.util.Hashtable;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.stream.StreamSource;

/**
 * The StylesheetManager is a class which is responsible for parsing and 
 * caching XSLT stylesheets. The stylesheet files are assumed to be
 * located in the classpath.
 */
public class StylesheetManager {
    /***properties*********************/
    protected TransformerFactory tFactory = TransformerFactory.newInstance();
    protected Class cls;
    protected ClassLoader classLoader;
    protected String path;
    protected Hashtable styles = new Hashtable();
    /***Constructor********************/
    /**
     * Creates a StylesheetManager object.
     * @param _cls the ClassLoader of this class is used to
     *             open stylesheet files
     * @param _p the path relative to _cls where the stylesheets
     *           can be found
     */
    public StylesheetManager(ClassLoader _cl, String _p) {
	classLoader = _cl;
	path = _p;
    }
    public StylesheetManager(Class _cls, String _p) {
	this(_cls.getClassLoader(), _p);
	cls = _cls;
    }
    protected Transformer loadStylesheet(String name) 
	throws TransformerException {
	InputStream is = null;
	if (classLoader!=null)
	    is = classLoader.getResourceAsStream(path+"/"+name+".xsl");
	if (is==null && cls!=null)
	    is = cls.getResourceAsStream(path+"/"+name+".xsl");
	if (is==null)
	    return null;
	return tFactory.newTransformer(new StreamSource(is));
    }
    /***Manager************************/
    /**
     * Clears the stylesheet cache. Use this method when you have
     * modified a stylesheet file in the classpath.
     */
    public void reload() {
	styles.clear();
    }
    /**
     * Loads a stylesheet from the cache. If it is not yet in
     * the cache, the stylesheet file is opened and parsed.
     * @param name the name of the stylesheet without the '.xsl' suffix
     */
    public Transformer getStylesheet(String name)
	throws TransformerException {
	Transformer style = (Transformer)styles.get(name);
	if (style==null) {
	    style = loadStylesheet(name);
	    if (style==null)
		return null;
	    styles.put(name, style);
	}
	return style;
    }
}
