/*
 *
 *  MakeLib
 *  Copyright (c) 1997-2001 Max Kellermann (max.kellermann@epost.de)
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation;
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: DOMSlotContainer.java,v 1.6 2001/12/19 16:59:44 max Exp $
 *
 */

package make.xml.slot;

import java.util.StringTokenizer;
import org.w3c.dom.Element;
import org.w3c.dom.Attr;
import org.w3c.dom.Node;
import make.datamodel.slot.Slot;
import make.datamodel.slot.SlotContainer;
import make.xml.DocumentType;
import make.xml.ElementType;
import make.xml.DOMUtil;
import make.xml.XPathUtil;
import make.util.Strings;

public class DOMSlotContainer implements SlotContainer {
    /***properties**********************/
    protected DocumentType documentType;
    protected Node context;
    /***Constructor**********************/
    public DOMSlotContainer(DocumentType _dt, Node _ctx) {
        documentType = _dt; context = _ctx;
    }
    /***SlotFactory***********************/
    public Slot getSlot(Object key) {
        if (key instanceof String) {
            /*NodeList nl = XPathUtil.execute((String)key, context).nodeset();
              if (nl.getLength()==0) {
              } else {
              Node n = nl.item(0);
              if (n instanceof Attr)
              return new AttributeSlot((Attr)n);
              else if (n instanceof Element)
              return new ElementSlot((Element)n);
              }*/
            String path = (String)key;
            StringTokenizer st = new StringTokenizer(path, "/");
            Element el = (Element)context;
            while (el!=null && st.hasMoreTokens()) {
                String t = Strings.trim(st.nextToken());
                if (t==null) {
                } else if (t.charAt(0)=='.') {
                    if (t.equals(".."))
                        el = (Element)el.getParentNode();
                    else if (!t.equals("."))
                        System.err.println("WARNING: unknown path "+t);
                } else if (t.charAt(0)=='@') {
                    String an = t.substring(1);
                    Attr a = el.getAttributeNode(an);
                    if (a==null) {
                        a = el.getOwnerDocument().createAttribute(an);
                        el.setAttributeNode(a);
                    }
                    ElementType et = documentType==null
                        ?null
                        :documentType.getElementType(el.getTagName());
                    return new AttributeSlot(a, et==null?null:et.getAttribute(an));
                } else {
                    Element ch = DOMUtil.getUniqueTag(el, t);
                    if (ch==null) {
                        ch = el.getOwnerDocument().createElement(t);
                        el.appendChild(ch);
                    }
                    el = ch;
                }
            }
            return new ElementSlot(context, path, el);
        } else
            return null;
    }
}
